dojo.provide("com.ibm.data.EnablerModelStore");

dojo.require("dojo.data.ItemFileWriteStore");
dojo.require("com.ibm.lang.DeferredQueue");
dojo.require("com.ibm.data._NotificationHelper");

dojo.declare("com.ibm.data.EnablerModelStore", 
		com.ibm.data._NotificationHelper,{
	// itemClass: String the class used to represent items of this store
	
	itemClass: "com.ibm.mm.enabler.navigation.NavigationNodeImpl",
	
	_isItemCreated: false,
	
	_isDirty: false,
	
	rootNode: null,
	
	globalPage: null,
	globalPageInSpace: null,
	
	constructor: function(){		
		this.navigationUtil = com.ibm.mm.builder.utils.navigationUtil;
		this.pageUtil = com.ibm.mm.builder.utils.pageUtil;
    	this.spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
    	var root = this.getRootNode();
		this.rootNode = root;
    },
    getRootNode: function(){
    	var pid = null;
    	var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
    	var items = [];
    	
		if(!currentPage){
			var spaceId = this.spaceUtil.getCurrentSpaceId();
			pid = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
		} else {
			pid = currentPage.getID();
		}
		if(!pid) return null;
		
		//update current page id and space id
		currentPage.setID(pid);
		
		var spaceId = this.spaceUtil.getSpaceIdByPageId(pid);
		if (spaceId !== this.spaceUtil.getCurrentSpaceId()) {
			this.spaceUtil.setSpaceId(spaceId);
		}
		//try to build model array
		var navModel = this.navigationUtil.getNavigationModel();
		var currentModel = navModel.find(pid).start();
		var rootId = this.navigationUtil.getNavigationRootNodeId();
		var currentSpaceRootId = this.navigationUtil.getNavigationRootNodeId(this.spaceUtil.getCurrentSpaceId());
		//Loop to root to build the menuModelArrays array that holds all the models of the item that need to be rendered
		while(currentModel && currentModel.getID() !== rootId && currentModel.getID() !== currentSpaceRootId) {
			items.push(currentModel);
			currentModel = navModel.getParent(currentModel.getID()).start();
		}
		return items[items.length - 1];
    },
    getFeatures: function(){
        return {'dojo.data.api.Read':true, 'dojo.data.api.Write':true, 'dojo.data.api.Identity':'id', "dojo.data.api.Notification": true };
    },

	/********************************/
	/**                            **/
	/**                            **/
	/**    dojo.data.api.Read      **/
	/**                            **/
	/**                            **/
	/********************************/
    getValue: function( /* item */ item, /* attribute-name-string */ attribute, 
                        /* value? */ defaultValue){
        var values = this.getValues(item, attribute);
        return (values.length > 0)?values[0]:defaultValue;
    },

    getValues: function(/* item */ item, /* attribute-name-string */ attribute){
		var values = null;
		switch(attribute) {
			case "id":
			    values = [item.getID()];
			    break;
			case "title":
				/* only needed in standalone mashups 
			    if (this.rootNode == item) values = ["Content Root"];
			    else*/ if (item.title) values = [item.title];
				else values = [this.pageUtil.getUnescapedPageTitle(item.getID())];
				break;
			case "description":
			    values = [this.pageUtil.getPageDescription(item.getID())];
				break;
			case "type":
			    values = item.type;
				break;
			case "parent":
				if (this.globalPage && item.openPageId && item.pageLoadedSpaceId===com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId()){
					// to support global page, open the faked new item under current parent
					if (dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid)){
						var lastNonGlobalPageId = dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid);
						var lastPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(lastNonGlobalPageId);
						var _navModel = this.navigationUtil.getNavigationModel();
						//TODO: need to update the logic here.
						var parent = _navModel.getParent(lastPage.getID()).start();
						values = [parent];						
					}else{
						console.log("Error: previous_pid in cookie is missing!");
					}					
				}else{
					var _navModel = this.navigationUtil.getNavigationModel();
					var parent = _navModel.getParent(item.getID()).start();
				    values = [parent];					
				}
				break;
			case "parentId":
				var _navModel = this.navigationUtil.getNavigationModel();
				var parent = _navModel.getParent(item.getID()).start();
	            var parentId = parent ? parent.getID() : null;
			    values = [parentId];
				break;
			case "children":
				var _navModel = this.navigationUtil.getNavigationModel();
				var childrenIter = _navModel.getChildren(item);
				var children = [];
			    while (childrenIter.hasNext()) {
					var child = childrenIter.next();
					var isVisible = com.ibm.mm.builder.utils.pageUtil.isVisiable(child);
					if(isVisible){ children.push(child); }
				}
				// support global page
				if (this.globalPage && this.globalPageInSpace===com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId()){
					children.push(this.globalPage);
				}
			    values = children;
				break;
			case "hasChildren":
				if(com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceNode() == item){ return false; }
				var _navModel = this.navigationUtil.getNavigationModel();
			    values = [_navModel.hasChildren(item)];
				break;
			default:
			    values = null;
		}
		values = (values && dojo.isArray(values)) ? values : [values];
		return values;
    },
    getAttributes: function(/* item */ item){
        return ["id", "title", "description", "type", "parent", "parentId", "children", "hasChildren"];
    },
    hasAttribute: function( /* item */ item, /* attribute-name-string */ attribute){
        return !!(this.getValue(item, attribute));
    },
    containsValue: function(/* item */ item, /* attribute-name-string */ attribute, /* anything */ value){
        return this.getValue(item, attribute) == value;
    },
    isItem: function(/* anything */ something){
    	//returns page node id if it is indeed an item
        return something.declaredClass == "com.ibm.mm.enabler.navigation.NavigationNodeImpl" && something.getID();
    },
    isItemLoaded: function(/* Object */ something) {
		// summary: All valid items in this data store are loaded all of the time as there
		//		is no support currently for stubs.  Therefore, this is effectively the same
		//		as isItem.
		return this.isItem(something) && something.loaded;
	},
	loadItem: function(/* Object */ keywordArgs){
		// summary: All valid items in this data store are loaded all of the time as there
		//			is no support currently for stubs.  Therefore, this function is a no-op. 
	},
    getLabel: function(/* item */ item){
        return this.getValue(item, "title");
    },
    getLabelAttributes: function(/* item */ item){
        return ["title"];
    },
    fetch: function(/* Object */ keywordArgs){
        if(!keywordArgs) keywordArgs = {};
        var me = this;
		keywordArgs.aborted = false;
		if(!keywordArgs.scope) keywordArgs.scope = dojo.global;
    	
        var query = keywordArgs.query;
        var items = []; 
        var _navModel = this.navigationUtil.getNavigationModel();
        
        if(query === null) {
        	items.push(this.rootNode);
        } else { 
        	var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
    		var pid = query.uri;
    		if(!pid){
    			var spaceId = spaceUtil.getCurrentSpaceId();
    			pid = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
    		}
			
    		//if current page still is null, this means no page exists.
    		if(pid) {
				if(com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId() == pid){
					// if navigating to a space with no pages, manually set up the selection path to the 
					// space root and content root, otherwise getChildren will fail
					items.push(com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceNode());
					items.push(this.navigationUtil.getNavigationRootNode());
				}else{
	    			var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
					currentPage.setID(pid);
					
					var spaceId = spaceUtil.getSpaceIdByPageId(pid);
					if (spaceId !== spaceUtil.getCurrentSpaceId()) {
						spaceUtil.setSpaceId(spaceId);
					}
					
					var navModel = this.navigationUtil.getNavigationModel();
					var currentModel = navModel.find(pid).start();
					//Loop to root to build the menuModelArrays array that holds all the models of the item that need to be rendered
					while(currentModel) {
						items.push(currentModel);
						currentModel = navModel.getParent(currentModel.getID()).start();
					}
				}
			}
        }
		items = this.processFetchedItems(items, keywordArgs);
		
		//TODO: implement getResultSize
		if(keywordArgs.onBegin) keywordArgs.onBegin.call(keywordArgs.scope, this.getResultSize(items.root, keywordArgs, items), keywordArgs);
		
		if(keywordArgs.onItem) {
			for(var i = 0; i < items.length; i++) {
				if(keywordArgs.aborted) return;
				keywordArgs.onItem.call(keywordArgs.scope, items[i], keywordArgs);
			}
		}
		
		if(keywordArgs.onComplete) {
			// call onComplete with items array if onItem wasn't specified, otherwise
			// call it with null
			if(keywordArgs.aborted) return;
			if(!keywordArgs.onItem) keywordArgs.onComplete.call(keywordArgs.scope, items, keywordArgs);
			else keywordArgs.onComplete.call(keywordArgs.scope, null, keywordArgs);
		}
	},
	processFetchedItems: function(items, keywordArgs){
		// do nothing
		return items;
	},
    getRootItem: function(){
        return this.rootNode;
    },    
	/********************************/
	/**                            **/
	/**                            **/
	/**    dojo.data.api.Identity  **/
	/**                            **/
	/**                            **/
	/********************************/
    getIdentity: function(/* item */ item){
        return this.getValue(item, "id");
    },
    getIdentityAttributes: function(/* item */ item){
        return ["id"];
    },
    fetchItemByIdentity: function(/* object */ keywordArgs){
        var node = this.pageUtil.getPageNode(getkeywordArgs.identify);
        node = node ? node : null;
        if(keywordArgs.onItem){
    		if(!keywordArgs.scope) keywordArgs.scope = dojo.global;
            keywordArgs.onItem.call(keywordArgs.scope, node);
        }
    },    
	/********************************/
	/**                            **/
	/**                            **/
	/**    dojo.data.api.Write     **/
	/**                            **/
	/**                            **/
	/********************************/
	deleteItem: function(/* item */ item){
		//	summary:
		//		Deletes an item from the store.
		//
		//	item: 
		//		The item to delete.
		//
		//	exceptions:
		//		Throws an exception if the argument *item* is not an item 
		//		(if store.isItem(item) returns false).
		//	example:
		//	|	var success = store.deleteItem(kermit);
		return false; // boolean
	},
	setValue: function(	/* item */ item, 
						/* string */ attribute,
						/* almost anything */ value){
		//	summary:
		//		Sets the value of an attribute on an item.
		//		Replaces any previous value or values.
		//
		//	item:
		//		The item to modify.
		//	attribute:
		//		The attribute of the item to change represented as a string name.
		//	value:
		//		The value to assign to the item.

		var lc = com.ibm.mashups.enabler.context.Factory.getLocalizedContext();    		
		switch(attribute) {
			case "id":
			    item.setID(value);
			    break;
			case "title":
				item.setTitle(value, lc.getLocale(item) || ibmConfig.locale);
				break;
			case "description":
			    item.setDescription(item, lc.getLocale(item) || ibmConfig.locale);
				break;
			case "type":
			    item.type = value;
				break;
			case "parent":
				// TODO?
				break;
			case "parentId":
				// TODO?
				break;
			case "children":
				// TODO?
				break;
			case "hasChildren":
				// TODO?
				break;
			case "position":
				var _navModel = com.ibm.mm.builder.utils.navigationUtil.getNavigationModel();
				_navModel.insert(item, value.newParent, value.next);
				item.loaded = false;
				item.created = true;
				if(value.oldParent == value.newParent){
					this.onSet(item, attribute, value.oldParent, value.next);
				}else if(value.next){
					this.onSet(item, "parent_next", value.oldParent, value.next);
				}else{
					this.onSet(item, "parent", value.oldParent, value.newParent);
				}
				break;
		}
	},
	newItem: function(/* Object? */ keywordArgs, /*Object?*/ parentInfo){
		// summary:
		//
        var title = keywordArgs.label;
    	var utils = com.ibm.mm.builder.utils;
    	var _navModel = utils.navigationUtil.getNavigationModel();
		
		var newPage;
		if (keywordArgs.openPageId){
			// load an existing page as an new item
			newPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(keywordArgs.openPageId);
			newPage.loaded = false;
			newPage.created = false;			
			newPage.openPageId = keywordArgs.openPageId;
			newPage.pageLoadedSpaceId = keywordArgs.pageLoadedSpaceId;
			newPage.onCreate = function(){}; 
			this.globalPageInSpace = newPage.pageLoadedSpaceId;
			this.globalPage = newPage;
		}else{
	        newPage = _navModel.create(null);
	        newPage.setTitle(title, dojo.locale);
	    	newPage.setTitle(title, ibmConfig["default.locale"]);
	    	var themeId = utils.themeUtil.getThemeId(parentInfo.parent.getID());
		    if (!utils.themeUtil.getThemeModel().find(themeId).start()){
		        themeId = utils.themeUtil.getDefaultThemeId();
		    }
		    newPage.setTheme(themeId);
			newPage.title = title;
			newPage.loaded = false;
			newPage.created = false;
			newPage.onCreate = function(){};  
			_navModel.insert(newPage, parentInfo.parent, null);
	
			// create layout
			var lm = _navModel.getLayoutModel(newPage.getID());
			var lmRoot = lm.create();
			lm.insert(lmRoot);
			// set empty fragment
			lmRoot.setFragment(" ");			
		}

		this.onNew(newPage, parentInfo);
		this._isItemCreated = true;
		return newPage;
	},
	isCreated: function(item) {
		return !!item.created;
	},
	addOnCreate: function(item, callback) {
		if(this.isCreated(item)) {
			callback(item);
		}
		else {
			if(!item.onCreateDefQueue) {
				item.onCreateDefQueue = new com.ibm.lang.DeferredQueue(new dojo.Deferred());
			}
			item.onCreateDefQueue.add((new dojo.Deferred()).addCallback(callback));
		}
	},
	_fireCreated: function(item) {
		if(item.onCreateDefQueue) {
			// TODO: open a global page twice will lead an exception.
			try{
				item.onCreateDefQueue.fire(item);
			}catch(ex){
				console.log(ex);
			}
		}
	},
	save: function(/* object */ keywordArgs){
		// summary:
    	var utils = com.ibm.mm.builder.utils;
    	var _navModel = utils.navigationUtil.getNavigationModel();
    	this.keywordArgs = keywordArgs;
		if (this.keywordArgs.openPageId){
			// just open an existing page, no need to save the page node.
			var newPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(this.keywordArgs.openPageId);
			if(this._isItemCreated){
				// create new items
				this.keywordArgs = keywordArgs;
				this.keywordArgs.item.onCreate();
				this.keywordArgs.item.created = true;
				this.keywordArgs.item.setID(newPage.getID());
				this._fireCreated(this.keywordArgs.item);
				this.onSaveComplete();
				this._isItemCreated = false;
				if(this.keywordArgs.onComplete) this.keywordArgs.onComplete(this.keywordArgs);
			}
		}else{
			if(this._isItemCreated){
				// create new items
				this.keywordArgs = keywordArgs;
				this.keywordArgs.item.onCreate();
		        var deferred = _navModel.commit();	
		        deferred.addFinishedCallback( dojo.hitch(this, function(node){
					this.keywordArgs.item.created = true;
			    	var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
					es.broadcastEvent("com.ibm.mashups.builder.pageCreated", node.getID());
					this.keywordArgs.item.setID(node.getID());
					this._fireCreated(this.keywordArgs.item);
		    		this.onSaveComplete();
		    		this._isItemCreated = false;
		    		if(this.keywordArgs.onComplete) this.keywordArgs.onComplete(this.keywordArgs);
		    	}));
		        deferred.start(false);
			}
			if(this._isDirty){
				// update dirty items
	        	_navModel.commit().start(false);
	        	this._isDirty = false;
	        	if(keywordArgs.onComplete) keywordArgs.onComplete(keywordArgs);
			}			
		}
	},
	
	revert: function(){
		//	summary:
		//		Discards any unsaved changes.
		//	description:
		//		Discards any unsaved changes.
		this._isItemCreated = false;
		this._isDirty = false;
		return false; // boolean
	},
    onSaveComplete: function(args) {
		// summary: Callers can attach listeners to this function to get notified when a save operation
		//		on this store has received its last response from the server for all write operations.
		//		This is called before callback handlers to the save function itself are called but after
		// 		all the responses for the requests to the server have returned.
	}
});