if(!dojo._hasResource["com.ibm.mashups.builder.IEvent"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.mashups.builder.IEvent"] = true;
dojo.provide("com.ibm.mashups.builder.IEvent");

/**
 * com.ibm.mashups.builder.IEvent defines all the public builder iEvents.<br/>
 * Usage: call com.ibm.mashups.builder.iEvents.SWITCH_PAGE to retreive the ievent name "com.ibm.mashups.builder.switchPage".<br/>
 * <br/>
 * 1. IEvent naming convention.<br/>
 * IEvent name such as <code>SWITCH_PAGE</code> and <code>PAGE_SWITCHED</code> followed the basic rules:<br/> 
 * (1) Verb + Noun:  the iEvent is broadcast before the action happen.<br/>
 * (2) Noun + Past Tense Verb:  the iEvent is broadcast after the action happen.<br/>
 * <br/>
 * 2. Terminology<br/>
 * (1) System iWidget: iWidget defined in theme.<br/>
 * (2) User iWidget: iWidget which user can add to a mashup page.<br/>
 * (3) Layout iWidget: a kind of system iWidget that manages user iWidget instances.<br/>
 * (4) None visible area: a kind of system iWidget that contains user iWidget instances in a hidden area.<br/>
 * (5) iWidget definition id: unique id of the iWidget metadata in enabler catalog API.<br/>
 * (6) iWidget instance id: unique id of the iWidget instance.<br/>
 * @ibm-api
 * @ibm-module Builder
 */

dojo.declare("com.ibm.mashups.builder.IEvent", null, {

	/**
	* <b>Description</b>: System iWidget should broadcast SWITCH_PAGE iEvent to switch to a given page.<br/>
	* Navigation iWidget must handle SWITCH_PAGE iEvent to switch page; 
	* after page is switched, iEvent <code>"com.ibm.mashups.builder.pageSwitched"</code> must be broadcast. <br/>
	* <b>Value</b>: "com.ibm.mashups.builder.switchPage"<br/>
	* <b>Payload</b>: id of page which will be switched to. Could be <code>null</code>. If null, Navigation iWidget will load current user's first page.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	SWITCH_PAGE: "com.ibm.mashups.builder.switchPage",
	
	/**
	* <b>Description</b>: Navigation iWidget must broadcast PAGE_SWITCHED iEvent after page is switched. <br/>
	* System iWidget can handle PAGE_SWITCHED iEvent to do follow-up work.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.pageSwitched"<br/>
	* <b>Payload</b>: id of page switched to. Could be <code>null</code> which means no page available for current user.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/	
	PAGE_SWITCHED: "com.ibm.mashups.builder.pageSwitched",
	
	/**
	* <b>Description</b>: System iWidget should broadcast SWITCH_SPACE iEvent to switch to a given space.<br/>
	* SpaceSelector iWidget must handle SWITCH_PAGE iEvent to switch space.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.switchSpace"<br/>
	* <b>Payload</b>: id of space which will be switched to. Could be <code>null</code>. If null, SpaceSelector iWidget will switch to personal space.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	SWITCH_SPACE: "com.ibm.mashups.builder.switchSpace",
	
	/**
	* <b>Description</b>: System iWidget broadcasts REFRESH_SPACE_SELECTOR iEvent to announce the space model has been changed.<br/>
	* SpaceSelector iWidget must handle REFRESH_SPACE_SELECTOR iEvent to retrieve the latest space model and re-render the UI.<br/>
	* For example, when user creates space within space manager, REFRESH_SPACE_SELECTOR iEvent must be broadcast to refresh Space Selector iWidget UI.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.refreshSpaceSelector"<br/>
	* <b>Payload</b>: id of space which title will be shown up in space selector. Could be <code>null</code>. If null, current space title will be used.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	REFRESH_SPACE_SELECTOR: "com.ibm.mashups.builder.refreshSpaceSelector",
	
	/**
	* <b>Description</b>: REFRESH_SPACE_LIST_IN_SPACE_MANAGER iEvent is broadcasted to refresh the space list in the space manager when space manager is opened<br/>
	* Space Manager iWidget must handle this iEvent to retrieve the latest space model and re-refresh the space list<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.spacemanager.refreshSpaceList"<br/>
	* <b>Payload</b>: N/A<br/> 
	* @type String
	*/
	REFRESH_SPACE_LIST_IN_SPACE_MANAGER: "com.ibm.mashups.builder.spacemanager.refreshSpaceList",
	
	/**
	* <b>Description</b>: System iWidget broadcasts REFRESH_NAVIGATION iEvent to announce the navigation model has been changed.<br/>
	* Navigation iWidget must handle REFRESH_NAVIGATION iEvent to retrieve the latest navigation model and re-render the UI.<br/>
	* For example, when user changes the page title, REFRESH_NAVIGATION iEvent must be broadcast to refresh Navigation iWidget UI.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.refreshNavigation"<br/>
	* <b>Payload</b>: N/A<br/> 
	* @type String
	*/
	REFRESH_NAVIGATION: "com.ibm.mashups.builder.refreshNavigation",
	
	/**
	* <b>Description</b>: System iWidget broadcasts REFRESH_PALETTE iEvent to announce the catalog model has been changed.<br/>
	* Palette iWidget must handle this iEvent to retrieve the latest catalog model and re-render the UI.<br/>
	* For example, when a new iWidget is added to Palette, REFRESH_PALETTE iEvent must be broadcast to refresh Palette.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.refreshPalette"<br/>
	* <b>Payload</b>: N/A<br/> 
	* @type String
	*/
	REFRESH_PALETTE: "com.ibm.mashups.builder.refreshPalette",
	
	/**
	* <b>Description</b>: System iWidget can broadcast LAYOUT_REFRESH iEvent to announce the layout model has been changed.<br/>
	* TemplateLayout iWidget handles LAYOUT_REFRESH iEvent to retrieve the latest layout model and re-render the UI.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.layoutRefresh"<br/>
	* <b>Payload</b>: id of layout container or control whose markup will be refreshed. Can be <code>null</code>. If null, entire layout (all containers) will be refreshed.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	LAYOUT_REFRESH: "com.ibm.mashups.builder.layoutRefresh",
	
	/**
	* <b>Description</b>: TemplateLayout iWidget broadcasts LAYOUT_REFRESHED iEvent after layout is done refreshing. <br/>
	* <b>Value</b>: "com.ibm.mashups.builder.layoutRefreshed"<br/>
	* <b>Payload</b>: <code>null</code> if entire layout was just refreshed. Or, id of individual layout container or control that was just refreshed.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	LAYOUT_REFRESHED: "com.ibm.mashups.builder.layoutRefreshed",
	
	/**
	* <b>Description</b>: System iWidget can broadcast REFRESH_CONTEXT_MENU iEvent to notify a context menu's listeners that it was updated.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.refreshContextMenu"<br/>
	* <b>Payload</b>: id of context menu whose listeners will be fired. Must not be <code>null</code>.
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	REFRESH_CONTEXT_MENU: "com.ibm.mashups.builder.refreshContextMenu",
	
	/**
	* <b>Description</b>: System iWidget can broadcast VIEW_HIDDEN_WIDGETS iEvent to show any hidden-widget containers on the page.<br/>
	* TemplateLayout iWidget handles VIEW_HIDDEN_WIDGETS iEvent to show any hidden-widget containers on the page.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.viewHiddenWidgets"<br/>
	* <b>Payload</b>: none; can be <code>null</code>.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	VIEW_HIDDEN_WIDGETS: "com.ibm.mashups.builder.viewHiddenWidgets",
	
	/**
	* <b>Description</b>: System iWidget can broadcast HIDE_HIDDEN_WIDGETS iEvent to hide any hidden-widget containers on the page.<br/>
	* TemplateLayout iWidget handles HIDE_HIDDEN_WIDGETS iEvent to hide any hidden-widget containers on the page.<br/>
	* <b>Value</b>: "com.ibm.mashups.builder.hideHiddenWidgets"<br/>
	* <b>Payload</b>: none; can be <code>null</code>.<br/>
	* <b>Payload type</b>: text <br/> 
	* @type String
	*/
	HIDE_HIDDEN_WIDGETS: "com.ibm.mashups.builder.hideHiddenWidgets",
	
	/**
	* <b>Description</b>: CHANGE_PAGE_MODE iEvent will be broadcast when page mode is changed. <br/>
	* System iWidgets can define CHANGE_PAGE_MODE iEvent as handled iEvent to update their UI accordingly. In current Lotus Mashups it only has 2 modes
	* ("view"/"edit"), but it's not limited to. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.changePageMode"<br/>
	* <b>Payload</b>: new page mode. Either "view" or "edit". Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/		
	CHANGE_PAGE_MODE: "com.ibm.mashups.builder.changePageMode",

	/**
	* <b>Deprecated</b>: ADD_WIDGET_FROM_TOOLBOX iEvent is replaced witch ADD_WIDGET.<br/>
	* <b>Description</b>: System iWidget can broadcast ADD_WIDGET_FROM_TOOLBOX iEvent to create a user iWidget instance.<br/>
	* Layout iWidget must define ADD_WIDGET_FROM_TOOLBOX iEvent as handled iEvent to create the user iWidget instance according to the payload<br/>
	* Base on the enabler CatalogModel API, system iWidget developer can get the user iWidget metadata according to user iWidget definition id.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.addWidgetFromToolbox"<br/>
	* <b>Payload</b>: this event could accept three kinds of payload.<br/>
	* &nbsp;-&nbsp;<b>Text</b>: It is the iWidget definition id. The definition id must a valid value in enabler CatalogModel API. Must not be <code>null</code>.<br/>. 
	* &nbsp;&nbsp;&nbsp;For example: "feedReader".<br/>
	* &nbsp;-&nbsp;<b>Json Object</b>: It includes widget definition id and itemset as preference. The itemset enable developer set/change preference of widget instance during widget rendering.<br/>
	* &nbsp;&nbsp;&nbsp;For example:<br/>
	* &nbsp;&nbsp;&nbsp;{id: "feedReader", itemset: {feedUrl:"http://www.ibm.com/feed.rss"} }.<br/>
	* &nbsp;-&nbsp;<b>Json Object</b>: It includes widget definition metadata and itemset as preference. The keys in widgetMetadata should be same as enabler API.<br/>
	* &nbsp;&nbsp;&nbsp;For example:<br/>
	* &nbsp;&nbsp;&nbsp;{<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;widgetMetadata: <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;{<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;id:"feedReader", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;definition:"/feedReader/feedReader.xml", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;icon: "/feedReader/feedreader.png", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;title:{en:"FeedReader", zh_CN:"yueduqi"},<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;onNewWire: "",<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;widgetParam: "[]"<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;}, <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;itemset: {feedURL:"http://www.ibm.com/feed.rss"} <br/>
	* &nbsp;&nbsp;&nbsp;}<br/>
	* <b>Payload type</b>: text or json<br/> 
	* @type String
	*/
	ADD_WIDGET_FROM_TOOLBOX: "com.ibm.mashups.builder.addWidgetFromToolbox",
	
	/**
	* <b>Description</b>: System iWidget can broadcast ADD_WIDGET iEvent to create a user iWidget instance.<br/>
	* Layout iWidget must define ADD_WIDGET iEvent as handled iEvent to create the user iWidget instance according to the payload<br/>
	* Base on the enabler CatalogModel API, system iWidget developer can get the user iWidget metadata according to user iWidget definition id.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.addWidget"<br/>
	* <b>Payload</b>: this event could accept three kinds of payload.<br/>
	* &nbsp;-&nbsp;<b>Text</b>: It is the iWidget definition id. The definition id must a valid value in enabler CatalogModel API. Must not be <code>null</code>.<br/>. 
	* &nbsp;&nbsp;&nbsp;For example: "feedReader".<br/>
	* &nbsp;-&nbsp;<b>Json Object</b>: It includes widget definition id and itemset as preference. The itemset enable developer set/change preference of widget instance during widget rendering.<br/>
	* &nbsp;&nbsp;&nbsp;For example:<br/>
	* &nbsp;&nbsp;&nbsp;{id: "feedReader", itemset: {feedUrl:"http://www.ibm.com/feed.rss"} }.<br/>
	* &nbsp;-&nbsp;<b>Json Object</b>: It includes widget definition metadata and itemset as preference. The keys in widgetMetadata should be same as enabler API.<br/>
	* &nbsp;&nbsp;&nbsp;For example:<br/>
	* &nbsp;&nbsp;&nbsp;{<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;widgetMetadata: <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;{<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;id:"feedReader", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;definition:"/feedReader/feedReader.xml", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;icon: "/feedReader/feedreader.png", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;title:{en:"FeedReader", zh_CN:"yueduqi"},<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;onNewWire: "",<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;widgetParam: "[]"<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;}, <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;itemset: {feedURL:"http://www.ibm.com/feed.rss"} <br/>
	* &nbsp;&nbsp;&nbsp;}<br/>
	* <b>Payload type</b>: text or json<br/> 
	* @type String
	*/
	ADD_WIDGET: "com.ibm.mashups.builder.addWidget",
	
	/**
	* <b>Description</b>: RESET_STYLE iEvent is broadcast to recreate a empty style of layout iWidget.<br/> 
	* Layout iWidget can define RESET_STYLE iEvent as handled iEvent to recreate style of itself.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.resetStyle"<br/>
	* <b>Payload</b>: N/A<br/>
	* @type String
	*/	
	RESET_STYLE: "com.ibm.mashups.builder.resetStyle",

	/**
	* <b>Description</b>: DISPLAY_WIDGET iEvent is broadcast to move a user iWidget instance from none visible area to layout iWidgets.<br/> 
	* Layout iWidget must define DISPLAY_WIDGET iEvent as handled iEvent to show a user iWidget instance in itself.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.displayWidget"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/	
	DISPLAY_WIDGET: "com.ibm.mashups.builder.displayWidget",

	/**
	* <b>Description</b>: HIDE_WIDGET iEvent is broadcast to move a user iWidget instance from layout iWidget to none visible area. <br/>
	* None visible area must define HIDE_WIDGET iEvent as handled iEvent to hide a user iWidget instance into itself.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.hideWidget"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	HIDE_WIDGET: "com.ibm.mashups.builder.hideWidget",

	/**
	* <b>Description</b>: RENAME_WIDGET iEvent is broadcast to rename a user iWidget instance. <br/>
	* Layout iWidget must define RENAME_WIDGET iEvent as handled iEvent to update the user iWidget instance name.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.renameWidget"<br/>
	* <b>Payload</b>: data of the updated user iWidget name. Must not be <code>null</code>. <br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;id: user iWidget instance id,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;name: new name of the user iWidget instance<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;locale(optional): locale of the name<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	RENAME_WIDGET: "com.ibm.mashups.builder.renameWidget",

	/**
	* <b>Description</b>: RENAME_ACTION iEvent is broadcast from iWidget context menu to inform another system iWidget to handle rename iWidget action. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.renameAction"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	RENAME_ACTION: "com.ibm.mashups.builder.renameAction",

	/**
	* <b>Description</b>: MOVE_ACTION iEvent is broadcast from iWidget context menu to inform another system iWidget to handle move iWidget action. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.moveAction"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	MOVE_ACTION: "com.ibm.mashups.builder.moveAction",
	
	/**
	* <b>Description</b>: RESIZE_ACTION iEvent is broadcast from iWidget context menu to inform another system iWidget to handle resize iWidget action. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.resizeAction"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	RESIZE_ACTION: "com.ibm.mashups.builder.resizeAction",
	
	/**
	* <b>Description</b>: CHANGE_SKIN iEvent is broadcast to change the skin of a user iWidget instance. <br/>
	* Layout iWidget must define CHANGE_SKIN iEvent as handled iEvent to update the skin of user iWidget instance. <br/>
	* Enabler ThemeModel will provide all the Skin available in current theme. Builder runtime model API will provide current theme Id. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.changeSkin"<br/>
	* <b>Payload</b>: user iWidget instance and the new skin id. The new skin id must be a valid skin id in enabler ThemeModel api.
	* Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;id: user iWidget instance id<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;skin: new skin name<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	CHANGE_SKIN: "com.ibm.mashups.builder.changeSkin",

	/**
	* <b>Description</b>: Mashup skin service broadcasts SKIN_LOADED iEvent when skin is loaded. <br/>
	* Layout iWidget could define SKIN_LOADED iEvent as handled iEvent if it needs to
	* initialize some additional handlers in user iWidget skin, such as drag and drop handler, resize handler. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.skinLoaded"<br/>
	* <b>Payload</b>: skin parameters. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetId: user iWidget instance id,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;skinNodeId: user iWidget skin node,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;skinParam: skin parameters defined in skin.js in the skin resource directory, json<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	SKIN_LOADED: "com.ibm.mashups.builder.skinLoaded",

	/**
	* <b>Description</b>: RESIZE_WIDGET iEvent should be broadcast to adjust the width or height of user iWidget instance. <br/>
	* Layout iWidget can define RESIZE_WIDGET iEvent as handled iEvent to update the size of user iWidget instance. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.resizeWidget"<br/>
	* <b>Payload</b>: size of user iWidget instance. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetId: id of user iWidget instance,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;width: new width of user iWidget instance,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;height: new height of user iWidget instance<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/	
	RESIZE_WIDGET: "com.ibm.mashups.builder.resizeWidget",

	/**
	* <b>Description</b>: WIDGET_RESIZED iEvent should be broadcast after the size of user iWidget instance is changed. <br/>
	* User iWidget can define WIDGET_RESIZED iEvent as handled iEvent to do some follow up work if necessary. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.widgetResized"<br/>
	* <b>Payload</b>: size of user iWidget instance. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetId: id of user iWidget instance,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;width: new width of user iWidget instance,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;height: new height of user iWidget instance<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/	
	WIDGET_RESIZED: "com.ibm.mashups.builder.widgetResized",
	
	/**
	* <b>Description</b>: WIDGET_MOVED iEvent should be broadcast after a user iWidget instance is moved in the layout. <br/>
	* User iWidget can define WIDGET_MOVED iEvent as handled iEvent to do some follow up work if necessary. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.widgetMoved"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/	
	WIDGET_MOVED: "com.ibm.mashups.builder.widgetMoved",
	
	/**
	* <b>Description</b>: WIDGET_DELETED iEvent should be broadcast after a user iWidget instance has been deleted from the layout. <br/>
	* User iWidget can define WIDGET_DELETED iEvent as handled iEvent to do some follow up work if necessary. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.widgetDeleted"<br/>
	* <b>Payload</b>: user iWidget instance id. Must not be <code>null</code>. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/	
	WIDGET_DELETED: "com.ibm.mashups.builder.widgetDeleted",

	/**
	* <b>Description</b>: System iWidget should broadcast EMBED_PAGE iEvent to embed a mashup page. <br/>
	* System iWidget (e.g EmbedPage) can define EMBED_PAGE iEvent as handled iEvent to accept to create the embedding UI for the page. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.embedPage"<br/>
	* <b>Payload</b>: page id. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	EMBED_PAGE: "com.ibm.mashups.builder.embedPage",

	/**
	* <b>Description</b>: System iWidget broadcasts EMBED_WIDGET iEvent to embed a user iWidget. <br/>
	* System iWidget (e.g EmbedWidget) can define EMBED_WIDGET iEvent as handled iEvent to create the embedding UI for the user iWidget. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.embedWidget"<br/>
	* <b>Payload</b>: user iWidget definition id. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	EMBED_WIDGET: "com.ibm.mashups.builder.embedWidget",
	
	/**
	* <b>Description</b>: System iWidget broadcasts LOAD_PAGESOURCE iEvent to load the page source. <br/>
	* System iWidget (e.g PageSource) can define LOAD_PAGESOURCE iEvent as handled iEvent to load the mashup page user iWidget markups into its source container. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.loadPageSource"<br/>
	* <b>Payload</b>: N/A<br/> 
	* @type String
	*/
	LOAD_PAGESOURCE: "com.ibm.mashups.builder.loadPageSource",

	/**
	* <b>Description</b>: System iWidget broadcasts SAVE_PAGE iEvent to save page source. <br/>
	* System iWidget (e.g PageSource) must define SAVE_PAGE iEvent as handled iEvent to persist the user iWidget markups in current page.<br/>
	* System iWidget developer can call enabler Navigation Model API to persist current page. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.savePage"<br/>
	* <b>Payload</b>: page id. Must not be <code>null</code>. <br/> 
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	SAVE_PAGE: "com.ibm.mashups.builder.savePage",

	/**
	* <b>Description</b>: PAGE_SAVED iEvent should be broadcast after the page has been saved. <br/>
	* User iWidget can define PAGE_SAVED iEvent as handled iEvent to do some follow up work if necessary. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.pageSaved"<br/>
	* <b>Payload</b>: page id. Must not be <code>null</code>. <br/> 
	* <b>Payload type</b>: text<br/> 
	* @type String
	* @since 3.0.0.2
	*/
	PAGE_SAVED: "com.ibm.mashups.builder.pageSaved",
	
	/**
	* <b>Description</b>: System iWidget broadcasts EDIT_PAGE iEvent to load page property. <br/>
	* System iWidget (e.g PagePropertyEditor) can define EDIT_PAGE iEvent as handled iEvent to load the page properties, for example, page theme and page title. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.editPage"<br/>
	* <b>Payload</b>: page id. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	EDIT_PAGE: "com.ibm.mashups.builder.editPage",

	/**
	* <b>Description</b>: System iWidget broadcasts UPDATE_PAGE_TITLE iEvent to update page title. <br/>
	* System iWidget (e.g PageTitle) can define UPDATE_PAGE_TITLE iEvent as handled iEvent to update the title in its displaying area. <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.updatePageTitle"<br/>
	* <b>Payload</b>: page title. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;title: page title,<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;locale(optional): locale of the title<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	UPDATE_PAGE_TITLE: "com.ibm.mashups.builder.updatePageTitle",
	
	/**
	* <b>Description</b>: System iWidgets broadcasts HIGHLIGHT_WIDGET iEvent to make Layout iWidget highlight a specific user iWidget.<br/>
	* Layout iWidget should define HIGHLIGHT_WIDGET iEvent as handled iEvent in case it wants to highlight a user iWidget instance.  <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.highlightWidget"<br/>
	* <b>Payload</b>: id of user iWidget instance. Must not be <code>null</code>. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	HIGHLIGHT_WIDGET: "com.ibm.mashups.builder.highlightWidget",
	
	/**
	* <b>Description</b>: System iWidgets broadcasts REMOVE_WIDGET_HIGHTLIGHT iEvent to make Layout iWidget remove highlight of a specific user iWidget.<br/>
	* Layout iWidget should define REMOVE_WIDGET_HIGHTLIGHT iEvent as handled iEvent in case it wants to remove the highlight on a user iWidget instance.  <br/>
    * <b>Value</b>: "com.ibm.mashups.builder.removeWidgetHighlight"<br/>
	* <b>Payload</b>: id of user iWidget instance. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	REMOVE_WIDGET_HIGHTLIGHT: "com.ibm.mashups.builder.removeWidgetHighlight",
	
	/**
	* <b>Description</b>: System iWidget broadcasts ADD_NEW_WIRE iEvent to inform layout iWidget to add a new wire. <br/>
	* Layout iWidget must define ADD_NEW_WIRE iEvent as handled iEvent, update the iWidget markup to add the new wire.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.addNewWire"<br/>
	* <b>Payload</b>: context information used to create new wire. Must not be <code>null</code>.<br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;sourceWidgetId: id of the wire's source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;sourceEvent: published event name of the source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetWidgetId: id of the wire's target iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetEvent: handled event name of the target iWidget<br/>
	* } <br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/	
	ADD_NEW_WIRE: "com.ibm.mashups.builder.addNewWire",
	
	/**
	* <b>Description</b>: System iWidget broadcasts REMOVE_NEW_WIRE iEvent to inform layout iWidget to remove an existing wire.<br/>
	* Layout iWidget must define REMOVE_NEW_WIRE iEvent as handled iEvent, update the iWidget markup to remove the wire.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.removeWire"<br/>
	* <b>Payload</b>: context information used to remove the wire. Must not be <code>null</code>.<br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;sourceWidgetId: id of the wire's source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;sourceEvent: published event name of the source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetWidgetId: id of the wire's target iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetEvent: handled event name of the target iWidget<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/	
	REMOVE_WIRE: "com.ibm.mashups.builder.removeWire",
	
	/**
	* <b>Description</b>: CREATE_AUTO_WIRE iEvent can be broadcast to add auto wire between the specified widget with other iWidget instances on the page. <br/>
	* Auto wire: Auto wire happens when<br/>
	* 1. Auto-wiring is enabled for the page;<br/>
	* 2. Specified iWidget is auto-wiring enabled;<br/>
	* 3. The wired-to iWidget is auto-wiring enabled;<br/>
	* 4. Wire the specified iWidget's iEvent to other iWidget's iEvent when the two iEvent have exactly same event name and payload type.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.createAutoWire"<br/>
	* <b>Payload</b>: iWidget instance id. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	CREATE_AUTO_WIRE: "com.ibm.mashups.builder.createAutoWire",
	
	/**
	* <b>Description</b>: AUTO_WIRE_CREATED iEvent will be broadcast to after a auto wire is added between two iWidget instances. <br/>
	* Auto wire: refer to the iEvent CREATE_AUTO_WIRE.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.autoWireCreated"<br/>
	* <b>Payload</b>: Created auto-wires information. Must not be <code>null</code>.<br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetId: instance id of the new added iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;publishTo: Array, contains all instance id of the widgets which the new added iWidget is wired with as source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;receiveFrom: Array, contains all instance id of the widgets which the new added iWidget is wired with as target iWidget<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	AUTO_WIRE_CREATED: "com.ibm.mashups.builder.autoWireCreated",
	
	/**
	* <b>Description</b>: CREATE_QUICK_WIRE iEvent can be broadcast to add a wire between two iWidget instances automatically. <br/>
	* Quick wire: Check the two iWidget's first iEvent, if they can be wired together(payload type is compatible), wire them. 
	* QUICK_WIRE_CREATED iEvent must be broadcast after the wire is created<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.createQuickWire"<br/>
	* <b>Payload</b>: context information used to add the wire. Must not be <code>null</code>.<br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;sourceWidgetId: id of the wire's source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetWidgetId: id of the wire's target iWidget<br/>
	* }<br/>
	* 
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	CREATE_QUICK_WIRE: "com.ibm.mashups.builder.createquickWire",
	
	/**
	* <b>Description</b>: QUICK_WIRE_CREATED iEvent will be broadcast to after a quick wire is added between two iWidget instances. <br/>
	* Quick wire: refer to the iEvent CREATE_QUICK_WIRE.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.quickWireCreated"<br/>
	* <b>Payload</b>: context information of the added wire. Must not be <code>null</code>.<br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;sourceWidgetId: id of the wire's source iWidget<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetWidgetId: id of the wire's target iWidget<br/>
	* }<br/>
	* 
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	QUICK_WIRE_CREATED: "com.ibm.mashups.builder.quickWireCreated",
	
	/**
	* <b>Description</b>: EDIT_WIRE iEvent can be broadcast to launch the wiring interface of a iWidget instance.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.editWire"<br/>
	* <b>Payload</b>: id of the user iWidget instance. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/	
	EDIT_WIRE: "com.ibm.mashups.builder.editWire",
	
	/**
	* <b>Description</b>: DISPLAY_WIRE_GRAPH iEvent can be broadcast to display the wire graph of a iWidget instance.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.displayWireGraph"<br/>
	* <b>Payload</b>: id of the user iWidget instance. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/	
	DISPLAY_WIRE_GRAPH: "com.ibm.mashups.builder.displayWireGraph",
	
	/**
	* <b>Description</b>: System iWidget broadcasts SHARE_PAGE iEvent to notice other iWidgets to start the sharing work.
	* System iWidget (e.g SharePage iWidget) which implements the sharing function should define this iEvent as handled iEvent<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.sharePage"<br/>
	* <b>Payload</b>: id of the shared page. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	SHARE_PAGE: "com.ibm.mashups.builder.sharePage",

	/**
	* <b>Description</b>: System iWidget broadcasts SHARE_SPACE iEvent to notice other iWidgets to start the sharing work.
	* System iWidget (e.g SharePage iWidget) which implements the sharing function should define this iEvent as handled iEvent<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.shareSpace"<br/>
	* <b>Payload</b>: id of the shared space. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	SHARE_SPACE: "com.ibm.mashups.builder.shareSpace",

	/**
	* <b>Description</b>: System iWidget broadcasts PUBLISH_PAGE iEvent to notice other iWidgets to start the publishing page work.
	* System iWidget (e.g PublishPage iWidget) which implements the publish function must define this iEvent as handled iEvent<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.publishPage"<br/>
	* <b>Payload</b>: id of the published page. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	PUBLISH_PAGE: "com.ibm.mashups.builder.publishPage",
	
	/**
	* <b>Description</b>: System iWidget broadcasts VIEW_MORE_PAGE iEvent to notice other iWidgets it wants to accept pages from other users.
	* System iWidget (e.g viewMorePage iWidget) which implements that function should define this iEvent as handled iEvent.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.viewMorePage"<br/>
	* <b>Payload</b>: N/A<br/>
	* @type String
	*/
	VIEW_MORE_PAGE: "com.ibm.mashups.builder.viewMorePage",
	
	/**
	* <b>Description</b>: DISPLAY_IN_MASHUP_DIALOG iEvent can be broadcast to display system iWidget in a configurable mashup dialog.<br/>
	* The system iWidget need to be linked to a type id in "dialogDisplayer" iWidget's itemset. <br/>
	* Current supported type id: 
	* <ul>
	* 	<li>sharePage</li>
	*   <li>publishPage</li>
	*   <li>viewMorePage</li>
	*   <li>renameWidget</li>
	*   <li>wireInteface</li>
	*   <li>pageSource</li>
	*   <li>embedPage</li>
	*   <li>embedWidget</li>
	*   <li>editPage</li>
	*   <li>hiddenWidgetCorral</li>
	*   <li>editSpace</li>
	*   <li>spaceManager</li>
	*   <li>createPage</li>
	*   <li>createSpace</li>
	*   <li>copySpace</li>
	*   <li>changeSpaceOwnerWidget</li>
	*   
	* </ul>
    * <b>Value</b>: "com.ibm.mashups.builder.displayInMashupDialog"<br/>
	* <b>Payload</b>: <br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetTypeId: type id. Must not be <code>null</code>.<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;eventName(optional): name of the iEvent of target iWidget which will be invoked <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;eventPayloa(optional): payload which will be passed to the handled iEvent<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;dialogParam(optional): parameters used to configure the dialog<br/>
	* }<br/>
	* Example: show wire interface iWidget in a dialog:<br/>
	* We have below definition in theme.html. <br/>
	* &lt;div class="mm_iWidget" id="dialogDisplayer"> <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&lt;a class="mm_Definition" href="/mum/widget-catalog/displayHelper.xml">&lt;/a> <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&lt;span class="mm_ItemSet" title="attributes" style="visibility: hidden; display: none;"> <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;a class="mm_Item" style="visibility: hidden; display: none;" href="#wireInterface">wireInterface&lt;/a> <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;....... <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;&lt;/span><br/>
	* &lt;/div> <br/>
	* Call following javascript code to display wire iWidget in dialog and invoke <code>EDIT_WIRE<code> iEvent.<br/>
	* var dialogParam = <br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;nodeWidth: "486px", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;...... <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;displayCloseButton: false, <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;hasRightBottomResizer: false <br/>
	* } <br/>
	* var payload = <br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetTypeId: "pageSoure", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;eventName:  "com.ibm.mashups.builder.loadPageSource", <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;eventPayload:  ..., <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;dialogParam:  dialogParam <br/>
	* }<br/>
	* var eventService = com.ibm.mashups.services.ServiceManager.getService("eventService"); <br/>
	* eventService.broadcastEvent("com.ibm.mashups.builder.displayInMashupDialog", payload);<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	DISPLAY_IN_MASHUP_DIALOG: "com.ibm.mashups.builder.displayInMashupDialog",
	
	/**
	* <b>Description</b>: CLOSE_MASHUP_DIALOG iEvent can be broadcast with a system iWidget id. 
	* If that system iWidget is displayed in a mashup dialog, then the dialog will be closed.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.closeMashupDialog"<br/>
	* <b>Payload</b>: id of the system iWidget instance which is displayed in the mashup style dialog. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
	CLOSE_MASHUP_DIALOG: "com.ibm.mashups.builder.closeMashupDialog",
		
	/**
	* <b>Description</b>: STATE_CHANGED iEvent can be broadcast to change the widget's state, restore/max/min the current widget by layout widget.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.stateChanged"<br/>
	* <b>Payload</b>: id of the iWidget instance, and widget's state. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;widgetId: iwidgetId, <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;state:  "max"/"min"/"normal" <br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
	STATE_CHANGED: "com.ibm.mashups.builder.stateChanged",
	
	/**
	* <b>Description</b>: Broadcast OPEN_PAGE iEvent to open a given page and optionally broadcast widget events to it.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.openPage"<br/>
	* <b>Payload</b>: This event can accept two kinds of payload, id of the page to be opened or a json object in the follow format. Must not be <code>null</code>.<br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;pid: id of the page to be opened<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;eventsArray: an array of events to be broadcast to the widgets on the page<br/>
	* }<br/>
	* The "eventsArray" should include one or more event objects in this format <br/>
	* { <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;targetEvent: targetEvent<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;payload: payload<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;payloadType: payloadType<br/>
	* }<br/>
	* <b>Payload type</b>: text or json<br/>
	* @type String
	*/
	OPEN_PAGE:"com.ibm.mashups.builder.openPage",
	
	/**
	* <b>Description</b>: Broadcast CLOSE_PAGE iEvent to close a given page that was opened using the OPEN_PAGE iEvent. If CLOSE_PAGE is broadcast multiple times, 
	* the actual close page action only happen once.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.closePage"<br/>
	* <b>Payload</b>: id of the page to be closed. <br/>
	* <b>Payload type</b>: text<br/> 
	* @type String
	*/
    CLOSE_PAGE:"com.ibm.mashups.builder.closePage",
	
	/**
	* <b>Description</b>: System iWidget broadcasts CREATE_PAGE iEvent to initiate Create Page widget, which allows to create a new page.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.createPage"<br/>
	* <b>Payload</b>: <code>spaceId</code> refers to under which space new page will be created, <code>parentPageId</code> refers to new page's parent page. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;spaceId: space id, <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;parentPageId: parent page id<br/>
	* }<br/>	
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
    CREATE_PAGE:"com.ibm.mashups.builder.createPage",

	/**
	* <b>Description</b>: System iWidget broadcasts CREATE_SPACE iEvent to initiate Create Space widget, which allows to create a new space.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.createSpace"<br/>
	* <b>Payload</b>: <code>createSpaceFromSpaceManager</code> should be set as <code>true</code> if CREATE_SPACE is broadcast inside Space Manager, otherwise <code>false</code>. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;createSpaceFromSpaceManager: a boolean value to indicate whether the create space action is launched from space manager<br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
    CREATE_SPACE:"com.ibm.mashups.builder.createSpace",

	/**
	* <b>Description</b>: System iWidget broadcasts EDIT_SPACE iEvent to initiate Edit Space widget, which allows to edit existing space.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.editSpace"<br/>
	* <b>Payload</b>: id of space to be edited. Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/>
	* @type String	
	*/
    EDIT_SPACE:"com.ibm.mashups.builder.editSpace",

	/**
	* <b>Description</b>: System iWidget broadcasts COPY_SPACE iEvent to initiate Copy Space widget, which allows to clone given space.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.copySpace"<br/>
	* <b>Payload</b>: <code>spaceId</code> is the id of space to be cloned, and <code>copySpaceInSpaceManager</code> should be set as <code>true</code> if COPY_SPACE is broadcast inside Space Manager, otherwise <code>false</code>. Must not be <code>null</code>.<br/>
	* {<br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;spaceId: id of the space, <br/>
	* &nbsp;&nbsp;&nbsp;&nbsp;copySpaceInSpaceManager: a boolean value to indicate whether the copy space action is launched from space manager <br/>
	* }<br/>
	* <b>Payload type</b>: json<br/> 
	* @type String
	*/
    COPY_SPACE:"com.ibm.mashups.builder.copySpace",		
	
	/**
	* <b>Description</b>: System iWidget broadcasts CHANGE_SPACE_OWNER iEvent to initiate Change Space Owner widget, which allows to change space owner. After space owner is changed, two dojo events will be published:<br/>
	* <code>dojo.publish("com.ibm.mm.builder.spaceEditorWidget.OwnerName", [username]);</code><br/>
	* <code>dojo.publish("com.ibm.mm.builder.spaceEditorWidget.OwnerId", [userid]);</code><br/>
	* These two dojo events should be subscribed to get new owner id and owner name.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.changeSpaceOwner"<br/>
	* <b>Payload</b>: original space owner id, Must not be <code>null</code>.<br/>
	* <b>Payload type</b>: text<br/>
	* @type String
	*/
    CHANGE_SPACE_OWNER:"com.ibm.mashups.builder.changeSpaceOwner",
	
	/**
	* <b>Description</b>: System iWidget broadcasts MANAGE_SPACES iEvent to initiate Space Manager widget, which allows to manage spaces.<br/>
    * <b>Value</b>: "com.ibm.mashups.builder.manageSpaces"<br/>
	* <b>Payload</b>: N/A<br/>
	* @type String
	*/
    MANAGE_SPACES:"com.ibm.mashups.builder.manageSpaces"	
});

com.ibm.mashups.builder.iEvents = new com.ibm.mashups.builder.IEvent();

}
