dojo.provide("com.ibm.pb.customize.enabler.TabbedController");

dojo.require("com.ibm.UnloadGuard");
dojo.require("com.ibm.widgets.InlineShelf");
dojo.require("dojo.i18n");
dojo.require("dojo.DeferredList");
dojo.requireLocalization("com.ibm.bundles", "Shelf", null, "ROOT,ar,ca,cs,da,de,el,en,es,fi,fr,he,hr,hu,it,ja,ko,nl,no,pl,pt,pt-br,ro,ru,sk,sl,sv,th,tr,uk,zh,zh-tw");

dojo.declare("com.ibm.pb.customize.enabler.TabbedController",
	[com.ibm.widgets.InlineShelf],
	{
		childrenArray: [],					// array of children to display in the tabs, each array item is an object {tabName:"",controller:object that implements the Customize Controller API}
		imagePath: '.',					// path to the css images
		hiddenClass: "lotusHidden",		// the css class name to hide content panes
		selectedClass: "lotusSelected",	// the css class to select tabs
		navModel: null,					// reference to the enabler navigation model
		widgetModel: null,				// reference to the enabler widget model
		selectedChild: null,			// the id of the currently selected child
		
		templateString: '<div class="lotusui ibmPortalCustomizeShelf lotusPalette" style="display: none;">' +
							'<div class="lotusPaletteHeader">' +							
							'<ul dojoAttachPoint="tabs" class="lotusTabs"></ul>' +
							'</div>' +
							'<div dojoAttachPoint="containerDivs"></div>' +
						'</div>',
		refreshRetryInterval: 300,		// if a refresh request is delayed because a save is pending, this is the amount of time to wait before retrying the refresh				
		
		constructor: function() {
			this.logger = com.ibm.mashups.enabler.logging.Logger.getLogger("com.ibm.pb.customize.enabler.TabbedController");
			this.logger.entering("contructor");
			this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.messages = dojo.i18n.getLocalization("com.ibm.bundles", "SharedMessages");
			this.okText = this.bundle["shelf_saveChanges"];
			this.cancelText = this.bundle["add_content_cancel"];
			this.eventService = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
	        this.eventService.subscribeEvent("com.ibm.mashups.builder.changePageMode", this, this.onPageModeChanged);
            this.saveInProgress = false;
            this.changedToPageViewMode = false;
            this.logger.exiting("contructor");
		},
		
		destroy: function() {
			dojo.forEach(this.childrenArray, function(child) {
				child.controller.destroy();
			});
			this.inherited(arguments);
		},

        /***********************************************/
        /*              Handle this event              */
        /***********************************************/
        
	    onPageModeChanged: function(iEvent){
	        var nsm = com.ibm.mashups.enabler.model.state.NavigationStateModelFactory.getNavigationStateModel();        
	        if(iEvent == "edit") {
	            nsm.startTransaction();
	        } else if(iEvent == "view") {
	            // if we are saving, then don't discard the transaction
	            // saveChildren() will commit the transaction if the page is actually saved
	            // or discard the transaction if the page is not saved, e.g. due to an error
	            // saveChildren() does need to know that a change to page view mode occurred
	            // also both saveInProgress and changedToPageViewMode will be reset in saveChildren()
	            if (this.saveInProgress)
	                this.changedToPageViewMode = true;
	            
	            // we are not saving, so just discard the transaction
	            else
                    nsm.discardTransaction();
	        }
	    },  
		
		/***********************************************/
		/*           Connect to these events           */
		/***********************************************/
		
		onFirstOpen: function(){
			// summary: stub event to be called the first time the shelf is opened
			this.logger.entering("onFirstOpen");
			this.fillTabs();
			this.logger.exiting("onFirstOpen");
		},
		
		onStartup: function(){
			// summary: stub event to be called when the TabbedController is started up
			this.logger.entering("onStartup");
			this.logger.exiting("onStartup");
		},
		
		onShowTab: function(/*Object*/selectedChild){
			// summary: stub event to be called whenever a tab is shown
			this.logger.entering("onShowTab",[selectedChild]);
			this.logger.exiting("onShowTab",[selectedChild]);
		},
		
		/***********************************************/
		/*         		  UI Functions    		       */
		/***********************************************/
		
		fillTabs: function(){
			// create the tabs and container divs for each child
			this.logger.entering("fillTabs");
			var count = 0, index = 0;
			dojo.forEach(
				this.childrenArray,
			    dojo.hitch(this, function(child){
					// create a node for the child to create its container
					var div = dojo.create("div",{className:this.hiddenClass,"id":this.id+count+"P","role":"tabpanel","aria-labelledby":this.id+count,"aria-hidden":"true"},this.containerDivs);
					dojo.place(child.controller.domNode,div);
					child.containerDiv = div;
					// create a tab div to access the container
					var tab = dojo.create("li");
					var tabName = dojo.create("a",{innerHTML:child.controller.tabLabel,href:"javascript:void(0)","role":"tab","id":this.id+count,"aria-controls":this.id+count+"P"},tab);
					dojo.place(tab,this.tabs);
					child.tab = tab;
					// create an onclick handler for each tab that opens its container
					tabName.onclick = dojo.hitch(this,this.showTab,child);
					if	(child.controller.id == this.selectedChild) {
						index = count;
					}
					count++;
			}));
			if(this.childrenArray.length == 0) {
				this.disconnectButton();
			} else {
				this.showTab(this.childrenArray[index]);
			}
			this.onStartup();
			this.logger.exiting("fillTabs");
		},
		
		showTab: function(/*Object*/selectedChild){
			// summary: displays the content pane for the given controller
			// selectedChild: the child to show
			this.logger.entering("showTab",[selectedChild]);
			if(!selectedChild.controller.started){
				// if the child isn't started yet, start it up
				selectedChild.controller.startup(this);
			}
			// clear all the tabs and container divs
			dojo.forEach(
				this.childrenArray,
			    dojo.hitch(this, function(child){
					dojo.removeClass(child.tab,this.selectedClass);
					dojo.addClass(child.containerDiv,this.hiddenClass);
					dojo.attr(child.containerDiv,"aria-hidden","true");
			}));
			// select and show the given child
			dojo.addClass(selectedChild.tab,this.selectedClass);
			dojo.removeClass(selectedChild.containerDiv,this.hiddenClass);
			dojo.attr(selectedChild.containerDiv,"aria-hidden","false");
			this.onShowTab(selectedChild);
			this.selectedChild = selectedChild.controller.id;
			this.logger.exiting("showTab",[selectedChild]);
			return false; /* to prevent onBeforeUnload event from triggering in IE */
		},
		
		refreshTabs: function(/*Array*/newChildren){
			// summary: refreshes the tabs shown in the UI
			// newChildren: the new array of child controllers to show
			var refresh = false;
			if (this.childrenArray.length != newChildren.length) {
				refresh = true;
			} else {
				for (var i = 0,l=newChildren.length; i < l; i++) {
					var found = false;
					for (var j = 0,l2 = this.childrenArray.length; j < l2; j++) {
						if (newChildren[i].controller.id == this.childrenArray[j].controller.id) {
							found = true;
							break;
						}
					}
					if (!found) {
						refresh = true;
						break;
					}
				}
			}
			if (refresh) {
				this.childrenArray = newChildren;
				if(!this.everOpened) { return; }
				while(this.containerDivs.children.length > 0){
					this.containerDivs.removeChild(this.containerDivs.firstChild);
				}
				while(this.tabs.children.length > 0){
					this.tabs.removeChild(this.tabs.firstChild);
				}
				this.fillTabs();
			}
		},
		
		clearSelectedTab: function(){
			// summary: sets the currently selected child to null
			this.selectedChild = null;
		},
		
		/***********************************************/
		/*         		  Model Functions  		       */
		/***********************************************/
		
		undoChildren: function(){
			// summary: undoes all pending changes in the children
			this.logger.entering("undoChildren");
			dojo.forEach( this.childrenArray, dojo.hitch(this, function(child){ 
				child.controller.undo();	
			}));
			this.logger.entering("exiting");
		},
		
		beforeSave: function(callback){
		    
			// summary: calls the beforeSave function for each child
			this.logger.entering("beforeSave",[callback]);

		    if(!this.childrenArray || this.childrenArray.length==0){callback();return}//BSpace removed the the first panel.
			// this.children.length is 0 in their UI 
			
			// onPageModeChanged() handler needs to know if a save is in progress
			// this will be reset in saveChildren()
			this.saveInProgress = true;
			
			this.closeOverlay = this.childrenArray[0].controller.showWaitMsgInDialog(this.bundle["shelf_saving"]);
			var dfdl = new dojo.DeferredList(dojo.map( this.childrenArray, function(child){
				return child.controller.beforeSubmit();
			}, this));
			// add the callback in a timeout or else it occurs so fast the overlay won't show
			setTimeout( dojo.hitch(this, function(){ dfdl.addCallback(dojo.hitch(this, callback)); }), 500 );
			this.logger.exiting("beforeSave",[callback]);
		},
		_setDialogErr: function(dialog, msg, callback){
			dialog.containerNode.innerHTML = msg;
			var footer = dojo.create("div", {
				className: "lotusDialogFooter"
			}, dialog.containerNode, "after");
			if(callback){
				dojo.create("button", {
					className: "lotusBtn",
					innerHTML: this.bundle.add_content_ok,
					onclick: function(){
						callback();
					}
				}, footer);
			}
		},
		saveChildren: function(callback){ 
			// summary: calls submit on each child
			this.logger.entering("saveChildren",[callback]);
			var nsm = com.ibm.mashups.enabler.model.state.NavigationStateModelFactory.getNavigationStateModel();
			var waitingDialog = null;
			if (this.childrenArray && this.childrenArray.length) {
			    waitingDialog = this.childrenArray[0].controller.waitingDialog;
			}
			var saveErr = null;
		
			var refresh = ibmCfg.themeConfig.alwaysRefreshOnPageSave || 
						  com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().isDirty();
			com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setDirty(false);
			var count = this.childrenArray.length;
			var counter = dojo.hitch(this,function(){
				this.logger.entering("counter in saveChildren",[count]);
				if(--count === 0) {
					// commit widget and navigation models
					var nCommit = this.navModel.commit();
					nCommit.setFinishedCallback(dojo.hitch(this,function(ctx){
						var status = ctx.statusCode;
						if(status == 200 || status == 201 || status == 400) {
							if(status >= 300 && waitingDialog){
								saveErr = true;
								var responseText = "";
								dojo.forEach(ctx.operations, function(op) {
									if (op.request && op.request.statusCode >= 300) {
										responseText += "<br><br>" + op.request.responseText;
									}
								}, this);
								this._setDialogErr(waitingDialog, this.messages.shelf_customizeError_0 + responseText, function(){
									window.location.reload();
								});
							}
							else {
								var wCommit = this.widgetModel.commit();
								wCommit.setFinishedCallback(dojo.hitch(this,function(x, status){
									if(status == 200 || status == 201 || status == 400) {
										if(status >= 300 && waitingDialog && !saveErr){
											saveErr = true;
											this._setDialogErr(waitingDialog, this.messages.shelf_customizeError_0, function(){
												window.location.reload();
											});
										}
										else {
											// save was sucessful, so commit the nsm transaction
											nsm.commitTransaction();
		
											// if we have NOT changed to page view mode we are still in edit mode
											// so start a new transaction
			                                if (!this.changedToPageViewMode)
			                                    nsm.startTransaction();
		
			                                if(refresh && !ibmCfg.themeConfig.savePageCheckerUnloading && (dojo.isOpera || ibmCfg.themeConfig.alwaysRefreshOnPageSave || !ibmCfg.themeConfig.isPageRenderModeCSA)) { com.ibm.utilities.refreshPage(); }
											else if (refresh) {
												this.eventService.broadcastEvent("com.ibm.mashups.builder.layoutRefresh");
											} 
											this.closeOverlay();
										}
									} else {
	                                    // we have changed to page view mode
									    // and not successfully saved
	                                    // so discard the nsm transaction
	                                    if (this.changedToPageViewMode)
	                                        nsm.discardTransaction();
	                                    // if we are still in edit mode
	                                    // then keep the nsm transaction
	                                    // since subsequent saves might work
	
										this.logger.severe("saveChildren","Cannot save the widget model", arguments);
										this.closeOverlay();
									}
									callback();
	
									// reset state members
									this.changedToPageViewMode= false;
						            this.saveInProgress = false;
								}));
								wCommit.start(false);
							}
						} else {
							this.logger.severe("saveChildren","Cannot save the navigation model", arguments);
							this.closeOverlay();
							callback();

                            // we have changed to page view mode
                            // and not successfully saved
                            // so discard the nsm transaction
                            if (this.changedToPageViewMode)
                                nsm.discardTransaction();
                            // if we are still in edit mode
                            // then keep the nsm transaction
                            // since subsequent saves might work

                            // reset state members
                            this.changedToPageViewMode = false;
                            this.saveInProgress = false;
						}
					}), null, true);
					nCommit.start(false);
				}
				this.logger.exiting("counter in saveChildren",[count]);
			});
			var handleError = dojo.hitch(this,function(errors){ 
			    // summary: publishes the given errors
				this.logger.entering("handleError in saveChildren",[errors]);
				counter();
				var message = this.bundle["add_content_addContentError"];
				var details = "";
				if(errors){
					message = errors[0].message;
					details = errors[0].responseText;
				}
				if(message.match(/\D401/)){ // Portal session not authenticated
					details = message;
					message = this.bundle["shelf_session_timeout"];
				}
				this.logger.severe("handleError in saveChildren",message + " : " + details,[errors]);
				this.logger.entering("handleError in saveChildren",[errors]);
			});
			dojo.forEach( this.childrenArray, function(child){ 
				if(child.controller.refresh && child.controller.dirty) { refresh = true; }
				child.controller.submit({onComplete:counter,onError:handleError});	
			}, this);
			this.logger.exiting("saveChildren",[callback]);
		}
});
