/* Copyright IBM Corp. 2010  All Rights Reserved. */
/* @author Laura
 * Summary: Page toolbar buttons for Page Builder 2:
 *			Customize
 *			Hidden Container
 *			Save
 *			Save & Exit
 *			Cancel
*/

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.utilities");
dojo.require("com.ibm.pb.iwidget.iWidgetBase");
dojo.require("dojo.i18n");
dojo.requireLocalization("com.ibm.bundles","Shelf");

dojo.declare("com.ibm.mm.builder.pageToolbarButtons", [dijit._Widget, dijit._Templated, com.ibm.pb.iwidget.iWidgetBase], {	 
	saveDisabled: false,		// true if the save and cancel buttons are disabled because there are no pending changes
	containersHidden: true,		// true if the hidden widget containers are hidden
	fadeTime: 500,				// time in ms it takes for the toolbar buttons to fade in or out of view
	newPage: false,				// true if a new page was just created
	shelfId: null,				// dijit id of the Customize shelf widget
	noTemplateLayout: false,	// true if the page does not use a template layout widget
	hiddenName: "ibmHiddenWidgets",		// name of the hidden widgets container
	editModeClass: "edit-mode",	// css class to add to the body element when in edit mode
	layoutMetadataKey: "com.ibm.portal.layout.template.ref",
	layoutFileMetadataKey: "com.ibm.portal.static.page.file.name.html",
	templateString: '<div class="lotusBtnContainer lotusui" dojoAttachPoint="buttonContainer" style="display:none;height:auto;" role="toolbar">' +
						'<button class="lotusBtn lotusBtnDisabled" aria-disabled="true" role="button" dojoAttachPoint="customizeButton" dojoAttachEvent="onclick:showOrHideCustomize" href="javascript:void(0)">${customizeString}</button>' +
						'<button class="lotusBtn" aria-disabled="false" role="button" dojoAttachPoint="hiddenButton" dojoAttachEvent="onclick:showOrHideContainers" href="javascript:void(0)" title="${showHiddenString}">${hiddenString}</button>' +
						'<button class="lotusBtn lotusHidden" aria-disabled="false" role="button" dojoAttachPoint="savePageButton" dojoAttachEvent="onclick:savePage" href="javascript:void(0)">${saveString}</button>' +
						'<button class="lotusBtn" aria-disabled="false" role="button" dojoAttachPoint="saveAndExitButton" dojoAttachEvent="onclick:savePageAndExit" href="javascript:void(0)">${saveAndExitString}</button>' +
						'<button class="lotusBtn" aria-disabled="false" role="button" dojoAttachPoint="cancelButton" dojoAttachEvent="onclick:cancelAll" href="javascript:void(0)">${cancelString}</button>' +
					'</div>',
		
    onLoad: function() {
		// put the contents of the dijit into the iwidget
		var contentDiv, rootId = this.iContext.getiWidgetAttributes().getItemValue("rootDomId");
		if(rootId) { contentDiv = dojo.byId(rootId); }
		if(!contentDiv) { contentDiv = dojo.query("." + com.ibm.mm.builder.constant.iwWidgetContent, this.iContext.getRootElement())[0]; }
		if(contentDiv) { contentDiv.appendChild(this.domNode); }
		else { this.iContext.getRootElement().appendChild(this.domNode); }
		this.shelfId = this.iContext.getiWidgetAttributes().getItemValue("shelfId");
		this.noTemplateLayout = this.iContext.getiWidgetAttributes().getItemValue("noTemplateLayout");
		if(!this.iContext.getiWidgetAttributes().getItemValue("hideSaveBtn")) {
			dojo.removeClass(this.savePageButton, "lotusHidden");
		}
	},

	postMixInProperties: function() {
		// initialize strings
		var bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
		this.customizeString = bundle["shelf_customize"];
		this.hiddenString = bundle["shelf_hiddenContainers"];
		this.hideHiddenString = bundle["shelf_hideHiddenContainers"];
		this.showHiddenString = bundle["shelf_showHiddenContainers"];
		this.saveString = bundle["shelf_saveChanges"];
		this.saveAndExitString = bundle["shelf_saveAndExit"];
		this.cancelString = bundle["add_content_cancel"];
	},
	
	postCreate: function(){
		// initialize animiations
		this.fadeIn = dojo.fx.wipeIn({node:this.buttonContainer, duration:this.fadeTime});
		this.fadeOut = dojo.fx.wipeOut({node:this.buttonContainer ,duration:this.fadeTime});		
	},
	
	/* ONCLICK HANDLERS */
	
	showOrHideCustomize: function() {
		if(!this.shelf) { this.shelf = dijit.byId(this.shelfId); }
		if (this.shelf) {
			// link customization button to shelf
			this.shelf.link = this.customizeButton;
			// summary: toggle the customize shelf
			if(this._isButtonEnabled(this.customizeButton)) {
				this.shelf.toggleDisplay();
			}
		}
	},
	
	showOrHideContainers: function() {
		// summary: publishes the viewHiddenWidgets or hideHiddenWidgets iEvents
		if(this.noTemplateLayout) {
			var hidden = dojo.query("[name^='"+this.hiddenName+"']");
			if(hidden.length < 1) { return; }
			var hiddenContainer = hidden[0];
			if(this.containersHidden) {
				hiddenContainer.style.display = "block"; 
				this.containersHidden = false;
				this.onViewHiddenWidgets();
			}
			else {
				hiddenContainer.style.display = "none"; 
				this.containersHidden = true;
				this.onHideHiddenWidgets();
			}
		} else {
			if(this.containersHidden) { this.evtSvc.broadcastEvent("com.ibm.mashups.builder.viewHiddenWidgets"); }
			else { this.evtSvc.broadcastEvent("com.ibm.mashups.builder.hideHiddenWidgets"); }
		}
	},
	
	savePage: function() {
		// summary: broadcast the savePage iEvent
		if(!this.saveDisabled) { this.evtSvc.broadcastEvent("com.ibm.mashups.builder.savePage"); }
	},
	
	savePageAndExit: function() {
		// summary: broadcast the savePage and changePageMode(view) iEvents
		this.savePage();
		if(!this.saveDisabled) { 
			if(ibmCfg.themeConfig.isPageRenderModeCSA){
				this._broadcastModeChange("view"); 
			} else {  // give time before changing modes on SSA pages in case a refresh interferes with the processing
				var me = this;
				setTimeout(function(){me._broadcastModeChange("view");},500);
			}
		}
	},
	
	cancelAll: function() {
        var nsm = com.ibm.mashups.enabler.model.state.NavigationStateModelFactory.getNavigationStateModel();        

        // summary: discards all pending changes in the enabler models and restores the UI
		var runtimePage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
		if(runtimePage.isDirty()){
			// undo shelf
			if(!this.shelf) { this.shelf = dijit.byId(this.shelfId); }
			this.shelf.undoChildren();
			if(ibmCfg.themeConfig.alwaysRefreshOnPageSave) {
				window.onbeforeunload = null;
				top.location.reload();
			} else {
				// get the current navigation node
				var pageId = runtimePage.getID();
				var navModel = com.ibm.mashups.enabler.navigation.Factory.getNavigationModel();
				var node = navModel.find(pageId).start();
				navModel.invalidate(node);
				com.ibm.mashups.enabler.widget.Factory.getWidgetModel().cachedWindows = {};
				
				// refresh the layout in the DOM
		        // 20705: setting the layout template URL to null has the desired effect of RenderingController.processControls() ignoring
				// any modifications to widget sizes (which is what we want since we're cancelling out of edit mode)  
				var layoutAccessor = com.ibm.mashups.enabler.model.state.AccessorFactory.getLayoutAccessor(nsm, pageId);
				layoutAccessor.setTemplateURL(null);
				var evtSvc = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
				evtSvc.broadcastEvent("com.ibm.mashups.builder.layoutRefresh");
				runtimePage.setDirty(false);
			}
		}
		this._broadcastModeChange("view");
	},
	
	/* IEVENT HANDLERS */
	
	onPageSwitched: function(iEvent) {
		// summary: go to edit mode if this is a new page, go to view mode otherwise
		var currentMode = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getPageMode();
		if((this.newPage && currentMode == "view") || (!this.newPage && currentMode == "edit")) {
			this._broadcastModeChange(this.newPage ? "edit" : "view");
			this.newPage = false;
		}
		// disable Customize button if user is not privileged
		if(this._canCustomize()) { this._enableButton(this.customizeButton); }
		else { this._disableButton(this.customizeButton); }
		// hide Hidden Content button on legacy pages
		// fix 16196 & 16471
		if (this.page.getNavigationElementType() == com.ibm.mashups.enabler.navigation.Constants.NAVIGATION_PAGE) {
			var content = this.page.getContent().start();
			if(!content.getMetaData(this.layoutMetadataKey)) { this._hideButton(this.hiddenButton); }
			else { this._showButton(this.hiddenButton); }
		}
    },
    
    onPageCreated: function(iEvent) {
		// summary: note that we are going to a new page
        //this.newPage = true;  fix for 17677
    },
	
	onPageModeChanged: function(iEvent) {
		// disable Customize button if user is not privileged
		if(this._canCustomize()) { this._enableButton(this.customizeButton); }
		else { this._disableButton(this.customizeButton); }
		
		// hide Hidden Content button on legacy pages and labels
		if (iEvent.payload == "edit") {
			if(this.page.getNavigationElementType() == com.ibm.mashups.enabler.navigation.Constants.NAVIGATION_PAGE){
				var content = this.page.getContent().start();
				if(!content.getMetaData(this.layoutMetadataKey)) { this._hideButton(this.hiddenButton); }
				else { this._showButton(this.hiddenButton); }
			} else {
				this._hideButton(this.hiddenButton);
			}
		}
		
		// summary: hides the buttons in view mode and shows them in edit mode
		if(iEvent.payload == "edit") {
			dojo.addClass(dojo.body(), this.editModeClass);
			if (!dojo.isIE && !dojo.isFF) {
				this.fadeIn.play();
			} else {
				this.buttonContainer.style.display = "";
			}
		} else {
			if(!this.containersHidden) {
				this.showOrHideContainers();
			}
			dojo.removeClass(dojo.body(), this.editModeClass);
			if (!dojo.isIE && !dojo.isFF) {
				this.fadeOut.play();
			} else {
				this.buttonContainer.style.display = "none";
			}
		}
	},
	
	onViewHiddenWidgets: function() {
		// summary: note that containers are not hidden
		this.hiddenButton.title = this.hideHiddenString;
		dojo.addClass(this.hiddenButton, "ibmCompressed");
		this.containersHidden = false;
	}, 
	
	onHideHiddenWidgets: function() {
		// summary: note that containers are hidden
		this.hiddenButton.title = this.showHiddenString;
		dojo.removeClass(this.hiddenButton, "ibmCompressed");
		this.containersHidden = true;
	},
	
	onview: function(){},
	
	onUnload: function(){},
	
	/* IEVENT HELPER FUNCTIONS */
	
	_broadcastModeChange: function(mode) {
		// broadcasts the changePageMode ievent with a mode payload
		var mname = "_broadcastModeChange";
		this.LOGGER.entering(mname, arguments);
		var currentMode = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getPageMode();
        var userModel = com.ibm.mashups.enabler.user.Factory.getUserModel();
		if (userModel.getAnonymousMode() != com.ibm.mashups.enabler.user.AnonymousMode.ANONYMOUS && currentMode != mode) {
			this.LOGGER.trace(mname, "Broadcasting mode change to ${0}", [mode]);
			if(dojo.isSafari || dojo.isOpera){
				var me = this;
				setTimeout(function(){me.evtSvc.broadcastEvent("com.ibm.mashups.builder.changePageMode", mode);},500);
			} else {
				this.evtSvc.broadcastEvent("com.ibm.mashups.builder.changePageMode", mode);
			}
			com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setPageMode(mode);
		}
		this.LOGGER.exiting(mname, arguments);
	},
	
	_canCustomize: function() { 
		// summary: returns true if the user can edit the current page
		var pageId = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getID();
		var pageDef = com.ibm.mashups.enabler.navigation.Factory.getNavigationModel().find(pageId);
		if(pageDef) {
			this.page = pageDef.start();
			var content = this.page.getContent().start();
			if(content.hasRole(com.ibm.mashups.enabler.ac.RoleType.EDITOR) || content.hasRole(com.ibm.mashups.enabler.ac.RoleType.ADMIN)){
				return true;
			} else if(content.hasRole("Privileged User")) { 
				if(!content.getMetaData(this.layoutMetadataKey) && !content.getMetaData(this.layoutFileMetadataKey)) { return false; }
				else { return true; }
			} else { return false; }
		} else { return false; }
	},
	
	/* UI HELPER FUNCTIONS */
	
	_isButtonEnabled: function(button) {
		return !dojo.hasClass(button, "lotusBtnDisabled");
	},
	
	_disableButton: function(button) {
		dojo.addClass(button, "lotusBtnDisabled");
		dojo.attr(button, "aria-disabled","true");
	},
	
	_enableButton: function(button) {
		dojo.removeClass(button, "lotusBtnDisabled");
		dojo.attr(button, "aria-disabled","false");
	},
	
	_hideButton: function(button) {
		dojo.addClass(button, "lotusHidden");
	},
	
	_showButton: function(button) {
		dojo.removeClass(button, "lotusHidden");
	},
	
	_onPageDirty: function() {
		// summary: enables the Save, Save & Exit and Cancel buttons
		// note: there is no way to tell when the page has been made dirty, so this is ununsed for now
		this.saveDisabled = false;
		this._enableButton(this.savePageButton);
		this._enableButton(this.saveAndExitButton);
		this._enableButton(this.cancelButton);
	},
	
	_onPageClean: function() {
		// summary: disables the Save, Save & Exit and Cancel buttons
		// note: there is no way to tell when the page has been made dirty, so this is ununsed for now
		this.saveDisabled = true;
		this._disableButton(this.savePageButton);
		this._disableButton(this.saveAndExitButton);
		this._disableButton(this.cancelButton);
	}
});
