# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2008, 2012. All rights reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

from java.lang import System
import java.io.File as File;
from java.util import Properties
from java.io import *
import sys
import java
import os
from os import listdir
import shutil

False = 0
True = 1
#------------------------------------------------------------------------------
# get the property value by the the property name; If property not available, return ''
#------------------------------------------------------------------------------
def getPropertyValue(propertyName):
	propertyValue = java.lang.System.getProperty(propertyName);
	if(propertyValue == None):
		return '';
	return propertyValue;
#endDef

#-----------------------------------------------------------------
# Logs messages
#-----------------------------------------------------------------
def trace(message):
    print message;
#endDef

#------------------------------------------------------------------------------
# Determine if the current platform is iSeries
#------------------------------------------------------------------------------
def isI5OS():
	propertyValue = java.lang.System.getProperty("os.name");
	if((propertyValue == "OS/400") or (propertyValue == "i5/OS")):
		return True
	return False
#endDef

#------------------------------------------------------------------------------
# Determine if the current platform is z/OS
#------------------------------------------------------------------------------
def isZOS():
	propertyValue = java.lang.System.getProperty("os.name");
	if((propertyValue == "OS/390") or (propertyValue == "z/OS")):
		return True
	return False
#endDef

#--------------------------------------------------------------
# Helper Class to normalize the string for comparision
#--------------------------------------------------------------
def wsadminToList(inStr):
	outList=[]
	if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
		tmpList = inStr[1:-1].split() #splits space-separated lists,
	else:
		tmpList = inStr.split("\n")   #splits for Windows or Linux
	for item in tmpList:
		item = item.rstrip();         #removes any Windows "\r"
		if (len(item)>0):
			outList.append(item)
	return outList;
#endDef

#-----------------------------------------------------------------
# Path utilities: 
# exists: return 1;
# not exist: return 0;
#-----------------------------------------------------------------
def existsPath(pathName):
	newPath=File(pathName);
	return newPath.exists();
#endDef
 
def normalizePath(pathName):
	newPath=File(pathName);
	return newPath.getAbsolutePath();
#endDef

#--------------------------------------------------------------
# Get Backup Folder for Migrtaing WPS Profile
#--------------------------------------------------------------
def getBackupDir():
	return getPropertyValue('wbi.upgrade.backup.dir');
	#return "E:\\backup601";
#endDef

#--------------------------------------------------------------
# Get Migrating WPS ProfileName
#--------------------------------------------------------------
def getPreviousProfileName():
	return getPropertyValue('wbi.upgrade.previous.profileName');
	#return "ProcSrv01";
#endDef

#--------------------------------------------------------------
# Get a value of WPSHOME.that is migrated to.
#--------------------------------------------------------------
def getWASHome():
	return getPropertyValue('was.install.root');
#endDef

#------------------------------------------------------------------------------
# get the was.repository.root
#------------------------------------------------------------------------------
def getRepository():
	return getPropertyValue('was.repository.root');
#endDef
	
#------------------------------------------------------------------------------
# get the profilePath.
#------------------------------------------------------------------------------
def getProfilePath():
        #return getPropertyValue('user.install.root');
	repositoryPath=getRepository();
	profilePath=File(repositoryPath).getParent();
	return profilePath;
#endDef

#------------------------------------------------------------------------------
# get the cell name
#------------------------------------------------------------------------------
def getCellName():
	return getPropertyValue('local.cell');
#endDef

#------------------------------------------------------------------------------
# get the node name
#------------------------------------------------------------------------------
def getNodeName():
	return getPropertyValue('local.node');
#endDef

#------------------------------------------------------------------------------
# get the node type: managed,unmanaged,
#------------------------------------------------------------------------------
def getNodeType():
	return getPropertyValue('wbi.upgrade.node.type');
#endDef

#------------------------------------------------------------------------------
# get the node type: managed,unmanaged,
#------------------------------------------------------------------------------
def getClusterName():
	return getPropertyValue('wbi.upgrade.cluster.name');
#endDef

#------------------------------------------------------------------------------
# get the scope Id according to cellname ,nodename, servername
#------------------------------------------------------------------------------
def getScopeId(cellName,nodeName,serverName):
	methodName = "getScopeId";
	framework.log("debug", scriptName, methodName, "Entering " + methodName)
	scopeId="";
	if (cellName ==''):
		scopeId='';
	elif (nodeName ==''):
		scopeId=AdminConfig.getid('/Cell:' + cellName);
	elif (serverName == ''):
		framework.log("debug", scriptName, methodName, " serverName empty, getting "+ cellName + ":" + nodeName)
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName);
	else:
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' +nodeName + '/Server:' + serverName);
	#endIf
	framework.log("debug", scriptName, methodName, "Exiting " + methodName)
	return scopeId;
#endDef

#------------------------------------------------------------------------------
# get the scope path according to cellname, nodename, servername
#------------------------------------------------------------------------------
def getScopePath(cellName,nodeName,serverName):
	methodName = "getScopePath";
	framework.log("debug", scriptName, methodName, "Entering " + methodName)
	scopePath="";
	if (cellName ==''):
		scopePath='';
	elif (nodeName ==''):
		scopePath='/Cell:' + cellName + '/';
	elif (serverName == ''):		
		scopePath='/Cell:' + cellName + '/Node:' + nodeName + '/';
	else:
		scopePath='/Cell:' + cellName + '/Node:' +nodeName + '/Server:' + serverName + '/';
	#endIf
	framework.log("debug", scriptName, methodName, "Exiting " + methodName)
	return scopePath;
#endDef

#------------------------------------------------------------------------------
# get the scope path according to cellname, clusterName
#------------------------------------------------------------------------------
def getClusterScopePath(cellName,clusterName):
	methodName = "getClusterScopePath";
	framework.log("debug", scriptName, methodName, "Entering " + methodName)
	scopePath="";
	if (cellName ==''):
		scopePath='';
	elif (clusterName ==''):
		scopePath='/Cell:' + cellName + '/';
	else:
		scopePath='/Cell:' + cellName + '/ServerCluster:' + clusterName + '/';
	#endIf
	framework.log("debug", scriptName, methodName, "Exiting " + methodName)
	return scopePath;
#endDef

#------------------------------------------------------------------------------
# check whether the update is required for current node;
# If true return 1, false return 0
#
#  If the nodeVersion is 6.1.x then update is required
#
#------------------------------------------------------------------------------
def checkIfUpdateIsRequired():
	methodName = "checkIfUpdateIsRequired";
	framework.log("debug", scriptName, methodName, "Entering " + methodName)
	
	result = False
	nodeVersion = getPropertyValue('wbi.upgrade.previous.was.version')
	
	framework.log("debug", scriptName, methodName, "nodeVersion is: " + str(nodeVersion))
	nodeVer = nodeVersion[0:3]
	framework.log("debug", scriptName, methodName, "nodeVer is: " + nodeVer)
	
	if (nodeVer == "6.1"):
		# This means any 6.1.x will be upgraded
		result = True
	else :
		# This means 6.0.2.x does not need upgrading
		result = False
	
	framework.log("debug", scriptName, methodName, "Exiting " + methodName)	
	return result
# endDef

#-----------------------------------------------------------------
# Check security:
#-----------------------------------------------------------------
def checkIfSecurityEnabled():
	security = AdminConfig.list('Security')
	return AdminConfig.showAttribute(security,"enabled") and AdminConfig.showAttribute(security,"appEnabled")
#endDef

#-----------------------------------------------------------------
# Check if BSpace has been configured:
#-----------------------------------------------------------------
def checkIfBSpaceMigrationRequired(scopeAtt, scopePath):
	methodName = "checkIfBSpaceMigrationRequired";
	framework.log("debug", scriptName, methodName, "Entering " + methodName)
        if checkDataSource("jdbc/bpm/BusinessSpace",scopePath):
        	framework.log("debug", scriptName, methodName, "Exiting " + methodName + " with TRUE")
        	return True
        elif checkDataSource("jdbc/mashupDS",scopePath):
        	framework.log("debug", scriptName, methodName, "Exiting " + methodName + " with TRUE")
        	return True
        else:
                framework.log("debug", scriptName, methodName, "Exiting " + methodName + " with FALSE")
                return False
        #endif	
	
#endDef

#-----------------------------------------------------------------
# Check to see if an action needs to be performed based on profileType
#-----------------------------------------------------------------
def checkProfileType(profileType):
	methodName = "checkProfileType";
	framework.log("debug", scriptName, methodName, "Entering " + methodName)
	result = False
	nodeType=getNodeType();
	if (profileType == "All"):
		result = True
	elif (profileType == nodeType):
		result = True
	framework.log("debug", scriptName, methodName, "Exiting " + methodName)
	return result
	
#endDef

#------------------------------------------------------------------------------
# check whether the specified application is installed 
#------------------------------------------------------------------------------
def checkApplicationExist(appName, scope):
	methodName = "checkApplicationExist";
	framework.log("debug", scriptName, methodName, "Entering " + methodName + "; Application -- " + appName)
	result = False
	applications = AdminApp.list(scope).split()
	for application in applications:
		if (application == appName):
			result = True
			framework.log("debug", scriptName, methodName, "Exiting " + methodName + " with " + str(result))
			return result
	framework.log("debug", scriptName, methodName, "Exiting " + methodName + " with " + str(result))
	return result
#endDef

#------------------------------------------------------------------------------
# check whether the specified datasource is configured
#------------------------------------------------------------------------------
def checkDataSource(jndiName, scopePath):
	methodName = "checkDataSource";
	framework.log("debug", scriptName, methodName, "Entering " + methodName + "; Data source -- " + jndiName)
	scope = AdminConfig.getid(scopePath)
	framework.log("debug", scriptName, methodName, "**************** scope:" + str(scope))
	if not scope:
		framework.log("debug", scriptName, methodName, "Exiting " + methodName + "; Data source -- " + jndiName)
		return False
	for dataSource in AdminConfig.list("DataSource", scope).splitlines():
		if (jndiName == AdminConfig.showAttribute(dataSource, "jndiName")):
			# candidate, but may be in a sub-scope. construct id in desired scope to make sure.
			provider = AdminConfig.showAttribute(dataSource, "provider")
			providerName = AdminConfig.showAttribute(provider, "name")
			# Robustness: apparently, there may be multiple JDBC providers with the same name. In this case
			# the originally used 'AdminConfig.getid(scopePath + "JDBCProvider:" + providerName + "/DataSource:" + dataSourceName + "/")'
			# will return an invalid config id that causes problems upstream.
			for provider in AdminConfig.getid(scopePath + "JDBCProvider:" + providerName + "/").splitlines():
				for dataSource2 in AdminConfig.list("DataSource", provider).splitlines():
					if dataSource == dataSource2:
						break
				#endfor
			#endfor
			if dataSource:
				return True
			#endif
		#endif
	#endfor
	
	framework.log("debug", scriptName, methodName, "Exiting " + methodName + "; Data source -- " + jndiName)
	return False
#enddef

#------------------------------------------------------------------------------
# Remove the specified datasource 
#------------------------------------------------------------------------------
def removeDataSource(jndiName, scopePath):
	scope = AdminConfig.getid(scopePath)
	if not scope:
		return False
	for dataSource in AdminConfig.list("DataSource", scope).splitlines():
		if (jndiName == AdminConfig.showAttribute(dataSource, "jndiName")):
			# candidate, but may be in a sub-scope. construct id in desired scope to make sure.
			provider = AdminConfig.showAttribute(dataSource, "provider")
			providerName = AdminConfig.showAttribute(provider, "name")
			# Robustness: apparently, there may be multiple JDBC providers with the same name. In this case
			# the originally used 'AdminConfig.getid(scopePath + "JDBCProvider:" + providerName + "/DataSource:" + dataSourceName + "/")'
			# will return an invalid config id that causes problems upstream.
			for provider in AdminConfig.getid(scopePath + "JDBCProvider:" + providerName + "/").splitlines():
				for dataSource2 in AdminConfig.list("DataSource", provider).splitlines():
					if dataSource == dataSource2:						
						break
				#endfor
			#endfor
			if dataSource:
				AdminConfig.remove(dataSource);
				return True
			#endif
		#endif		
	#endfor
	return False
#enddef

#-----------------------------------------------------------------
# Uninstall Outdated Business Space Runtime
#-----------------------------------------------------------------
def uninstallPreBSpaceRuntime(scope):	
	uninstallApp("All", "BusinessSpaceManager", scope)
	uninstallApp("All", "IBM_BSPACE_WIDGETS", scope)	
		
#endDef

#-----------------------------------------------------------------
# Uninstall Outdated OOB Widiget Application
#-----------------------------------------------------------------
def uninstallPreOOBWidgetApp(scope):	
	uninstallApp("All", "HumanTaskManagementWidgets", scope)
	uninstallApp("All", "WorkOrganizerWidgets", scope)	
	uninstallApp("All", "BSpaceITWidgets", scope)
		
#endDef


#-----------------------------------------------------------------
# Uninstall an app
#-----------------------------------------------------------------
def uninstallApp(profileType, appName, scope):
	methodName = "uninstallApp";
	framework.log("debug", scriptName, methodName, "Entering " + "uninstallApp("+profileType+","+appName+ ")")
	if ((checkProfileType(profileType) == True) and (checkApplicationExist(appName, scope) == True)):
		framework.log("debug", scriptName, methodName, "uninstalling application "+appName)
		try:
			AdminApp.uninstall(appName)
			framework.log("debug", scriptName, methodName, "uninstall application "+appName+" was successful")
		except:
			framework.log("debug", scriptName, methodName, "uninstall application "+appName+" failed. Application may not be installed.")
	#endif	
	framework.log("debug", scriptName, methodName, "Exiting " + "uninstallApp("+profileType+","+appName+ ")")
#endDef

#-----------------------------------------------------------------
# Setup Business Space V8
#-----------------------------------------------------------------
def installBusinessSpace(serverName, nodeName, clusterName, configEnv):
	methodName = "installBusinessSpace";
	framework.log("debug", scriptName, methodName, "Entering " + "installBusinessSpace")
	if clusterName == '':
		arr = '[-serverName "' + serverName + '" -nodeName "' + nodeName + '" -configEnv "' + configEnv + '" -deployFormsEAR false]'
	else:
		arr = '[-clusterName "' + clusterName + '" -configEnv "' + configEnv + '" -deployFormsEAR false]'
	#Install Business Space
	AdminTask.installBusinessSpace(arr)

	#Configure Business Space for migration
	#AdminTask.configureBusinessSpaceForMigration(arr)
	framework.log("debug", scriptName, methodName, "Exiting " + "installBusinessSpace")
#endDef

#-----------------------------------------------------------------
# Check BSpace version info:
#-----------------------------------------------------------------
def checkBSpaceVersion(nodeName, serverName, clusterName, scopeAtt, scopePath):
	suffix = '';
        if clusterName == '':
                suffix = '_' + nodeName + '_' + serverName;
	else :
		suffix = '_' + clusterName;
        #endif
        
	if (checkDataSource("jdbc/bpm/BusinessSpace",scopePath)):
	        return 'v6';
	elif (checkApplicationExist('PageBuilder2' + suffix,scopeAtt)):
		return 'v7.5';
	else :
		return 'v7.0';
	#endif
	
#endDef

#-----------------------------------------------------------------
# Update Business Space to v80
#-----------------------------------------------------------------
def updateBusinessSpace(serverName, nodeName, clusterName, version, configEnv):
	methodName = "updateBusinessSpace";
	framework.log("debug", scriptName, methodName, "Entering " + "updateBusinessSpace")
	if clusterName == '':
		arr1 = '[-serverName "' + serverName + '" -nodeName "' + nodeName + '" -sourceVersion "' + version + '" -configEnv "' + configEnv + '"]'
	else:
		arr1 = '[-clusterName "' + clusterName + '" -sourceVersion "' + version + '" -configEnv "' + configEnv + '"]'
	#Install Business Space
	AdminTask.updateBusinessSpaceRuntimeForMigration(arr1)

	if clusterName == '':
		arr2 = '[-serverName "' + serverName + '" -nodeName "' + nodeName + '" -sourceVersion "' + version + '"]'
	else:
		arr2 = '[-clusterName "' + clusterName + '" -sourceVersion "' + version + '"]'
	#Configure Business Space for migration
	AdminTask.configureBusinessSpaceForMigration(arr2)
	framework.log("debug", scriptName, methodName, "Exiting " + "updateBusinessSpace")
#endDef

#-----------------------------------------------------------------
# Update Business Space Widgets for Monitor v75
#-----------------------------------------------------------------
def updateMonitorWidgets(serverName, nodeName, clusterName):
	methodName = "updateMonitorWidgets";
	framework.log("debug", scriptName, methodName, "Entering " + "updateMonitorWidgets")
	wasHome = getWASHome();
	if clusterName == '':
		arr = '[-serverName "' + serverName + '" -nodeName "' + nodeName + '" -widgets "' + wasHome + '/BusinessSpace/registryData/WBM/widgets/Widgets_WBMonitor.zip" -noEndpoints true]'
	else:
		arr = '[-clusterName "' + clusterName + '" -widgets "' + wasHome + '/BusinessSpace/registryData/WBM/widgets/Widgets_WBMonitor.zip" -noEndpoints true]'
	
	framework.log("debug", scriptName, methodName, "parameters -- " + arr)
	
	#Update Monitor Widgets	
	AdminTask.updateBusinessSpaceWidgets(arr)
	
	if clusterName == '':
		arr2 = '[-serverName "' + serverName + '" -nodeName "' + nodeName + '" -widgets "' + wasHome + '/BusinessSpace/registryData/WBM/widgets/Widgets_Cognos.zip"]'
	else:
		arr2 = '[-clusterName "' + clusterName + '" -widgets "' + wasHome + '/BusinessSpace/registryData/WBM/widgets/Widgets_Cognos.zip"]'
	
	framework.log("debug", scriptName, methodName, "parameters -- " + arr2)
	
	#install Cognos Widgets	
	AdminTask.installBusinessSpaceWidgets(arr2)

	framework.log("debug", scriptName, methodName, "Exiting " + "updateMonitorWidgets")
#endDef

final_file_list = []

#-----------------------------------------------------------------
# Update Business Space importing flags
#-----------------------------------------------------------------
def updateImportingFlags():
	methodName = "updateImportingFlags";
	framework.log("debug", scriptName, methodName, "Entering " + "updateImportingFlags")
        
        profileRoot = getProfilePath();
        fileName = "oobLoadedStatus.properties"
        
	if existsPath(profileRoot + '/BusinessSpace'):
		find_file_by_pattern(profileRoot + '/BusinessSpace')
	#endif
	
	framework.log("debug", scriptName, methodName, str(final_file_list))
	
	for refile in final_file_list:
		if File(refile).getName() == fileName:
			prop = Properties()				
			prop.load(FileInputStream(refile))			
			importThemes = prop.getProperty("importThemes.txt")
			prop.setProperty("importThemes.txt", 'true')
			importSpaces = prop.getProperty("importSpaces.txt")
			prop.setProperty("importSpaces.txt", 'true')
			importTemplates = prop.getProperty("importTemplates.txt")
			prop.setProperty("importTemplates.txt", 'true')
			#print "importThemes=" + importThemes
			prop.save(FileOutputStream(refile), '')
		#endif
	
	framework.log("debug", scriptName, methodName, "Exiting " + "updateImportingFlags")
#endDef

#-----------------------------------------------------------------
# 
#-----------------------------------------------------------------
def find_file_by_pattern(parent):
	pattern='.*'
	re_file = re.compile(pattern)
	
	cur_list = os.listdir(parent) 
	
	for item in cur_list:
		full_path = os.path.join(parent, item)
		#print full_path 
		if os.path.isfile(full_path):
			final_file_list.append(full_path) 
		else: 
			find_file_by_pattern(full_path) 
	
	#return final_file_list
#endDef

#-----------------------------------------------------------------
# Copy Business Space system files
#-----------------------------------------------------------------
def copyBusinessSpaceSystemFiles():
        methodName = "copyBusinessSpaceSystemFiles";
	framework.log("debug", scriptName, methodName, "Entering " + "copyBusinessSpaceSystemFiles")
	wasHome = getWASHome();
	framework.log("debug", scriptName, methodName, "WAS Home -- " + wasHome)
	profileRoot = getProfilePath();
	framework.log("debug", scriptName, methodName, "Profile Root -- " + profileRoot)
	#existsPath(pathName)
	if existsPath(profileRoot + '/BusinessSpace'):
		if not existsPath(profileRoot + '/BusinessSpace.system'):
		        copyDirectory(wasHome + '/BusinessSpace/mm.runtime/public/files', profileRoot + '/BusinessSpace.system/files')
		        copyDirectory(wasHome + '/BusinessSpace/themes', profileRoot + '/BusinessSpace.system/themes')
		#endif
	#endif
	framework.log("debug", scriptName, methodName, "Exiting " + "copyBusinessSpaceSystemFiles")
#endDef

#-----------------------------------------------------------------
# Utility -- copy directory
#-----------------------------------------------------------------
def copyDirectory(sourceDir, targetDir):
	methodName = "copyDirectory";
	framework.log("debug", scriptName, methodName, "Entering " + "copyDirectory; From " + str(sourceDir) + " To " + str(targetDir))
	framework.log("debug", scriptName, methodName, "source directory -- " + sourceDir)
	framework.log("debug", scriptName, methodName, "target directory -- " + targetDir)
	
	if not os.path.exists(targetDir):   
                os.makedirs(targetDir)
	
	#copyFileCounts = 0
    
        for f in os.listdir(sourceDir):   
                sourceF = os.path.join(sourceDir, f)   
                targetF = os.path.join(targetDir, f)   
                 
                if os.path.isfile(sourceF):                        
                        #copyFileCounts += 1
                        shutil.copy(sourceF, targetF)
                elif os.path.isdir(sourceF):   
                        copyDirectory(sourceF, targetF)
                #endif            
	framework.log("debug", scriptName, methodName, "Exiting " + "copyDirectory; From " + str(sourceDir) + " To " + str(targetDir))
#endDef

#-----------------------------------------------------------------
# Main program:
#-----------------------------------------------------------------
def main():
        methodName = "main";
        
	framework.log("info", scriptName, methodName, "Entering " + scriptName)
	
	profileType = getPropertyValue('bpm.upgrade.profile.type')
	framework.log("info", scriptName, methodName, "BPM Profile Type is -- " + str(profileType))
	profileType2 = getPropertyValue('wbi.upgrade.profile.type')
	framework.log("info", scriptName, methodName, "WBI Profile Type is -- " + str(profileType2))
	nodeType = getPropertyValue('wbi.upgrade.node.type')
	framework.log("info", scriptName, methodName, "WBI Upgrade Node Type is -- " + str(nodeType))
	
	# if success, it is 1, otherwise, it is 0.
	flag_success=1;
	failureReason="";

	clusterName = getClusterName()
	if clusterName == "":
		clusterName = None
	#endif

	nodeName = getNodeName()
	framework.log("debug", scriptName, methodName, "nodeName=" + nodeName)
	cellName = getCellName()
	framework.log("debug", scriptName, methodName, "cellName=" + cellName)
	
	if (nodeType != 'managed'):
		if clusterName:
			framework.log("info", scriptName, methodName, "clusterName = " + clusterName)
			scopeAtt = 'WebSphere:cell=' + cellName + ',cluster=' + clusterName
			scopePath = getClusterScopePath(cellName,clusterName)
			if (not checkIfBSpaceMigrationRequired(scopeAtt,scopePath)):				
				framework.log("info", scriptName, methodName, "No Business Space configured in target cluster, exit Business Space migration in target cluster")
				#trace("No Business Space configured in target cluster, exit Business Space migration in target cluster");
				return;
			#endif
			
			version = checkBSpaceVersion('', '',clusterName,scopeAtt,scopePath)
			framework.log("info", scriptName, methodName, "source version -- " + version)
			
			if (version == 'v6'):
			        uninstallPreOOBWidgetApp(scopeAtt)
			        #bpm.upgrade.profile.type=wbiserver
				#wbi.upgrade.profile.type=WPS
				if (profileType != None):
					if (profileType2 != None):
						if(profileType == 'wbiserver'):
							if(profileType2 == 'WPS'):
								framework.log("info", scriptName, methodName, "Migrate Business Space for bpm_adv.")
								installBusinessSpace('', '', clusterName, 'bpm_adv')
								updateBusinessSpace('', '', clusterName, 'v6', 'bpm_adv')
							#endif
						else:
							framework.log("info", scriptName, methodName, "Migrate Business Space for bspace.")
							installBusinessSpace('', '', clusterName, 'bspace')
							updateBusinessSpace('', '', clusterName, 'v6', 'bspace')
						#endif
					#endif	
				#endif
			        
			        sys.argv = ['-usedefault', '-clusterName', clusterName]
				execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py', {})
			        
			        uninstallPreBSpaceRuntime(scopeAtt)
			        removeDataSource("jdbc/bpm/BusinessSpace",scopePath)
			        framework.log("info", scriptName, methodName, "******************************************* Message begin for remote endpoint *******************************************")
			        framework.log("info", scriptName, methodName, "If you have Business Space widgets enabled for remote endpoint in source installation, you must migrate them manually to the target installation.")
			        framework.log("info", scriptName, methodName, "Please see the topic 'Postmigration tasks for Business Space powered by WebSphere' in InfoCenter.")
			        framework.log("info", scriptName, methodName, "******************************************* Message end for remote endpoint *******************************************")
			elif (version == 'v7.0'):
				#bpm.upgrade.profile.type=wbiserver
				#wbi.upgrade.profile.type=WPS
				if (profileType != None):
					if (profileType2 != None):
						if(profileType == 'wbiserver'):
							if(profileType2 == 'WPS'):
								framework.log("info", scriptName, methodName, "Migrate Business Space for bpm_adv.")
								updateBusinessSpace('', '', clusterName, 'v70', 'bpm_adv')
							#endif
						else:
							framework.log("info", scriptName, methodName, "Migrate Business Space for bspace.")
							updateBusinessSpace('', '', clusterName, 'v70', 'bspace')
						#endif
					#endif	
				#endif
				
				sys.argv = ['-usedefault', '-clusterName', clusterName]
				execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py', {})
				
				framework.log("debug", scriptName, methodName, "Profile Type is : " + profileType)
				if (profileType.find('wbmonitor') >= 0):
					framework.log("debug", scriptName, methodName, "It is a Monitor profile migration")
					framework.log("debug", scriptName, methodName, "update Monitor widgets")
					updateMonitorWidgets('', '', clusterName)
			elif (version == 'v7.5'):
				#bpm.upgrade.profile.type=wbiserver
				#wbi.upgrade.profile.type=WPS
				if (profileType != None):
					if (profileType2 != None):
						if(profileType == 'wbiserver'):
							if(profileType2 == 'WPS'):
								framework.log("info", scriptName, methodName, "Migrate Business Space for bpm_adv.")
								updateBusinessSpace('', '', clusterName, 'v75', 'bpm_adv')
							#endif
						else:
							framework.log("info", scriptName, methodName, "Migrate Business Space for bspace.")
							updateBusinessSpace('', '', clusterName, 'v75', 'bspace')
						#endif
					#endif	
				#endif			
				
				sys.argv = ['-usedefault', '-clusterName', clusterName]
				execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py', {})
				
				framework.log("debug", scriptName, methodName, "Profile Type is : " + profileType)
				if (profileType.find('wbmonitor') >= 0):
					framework.log("debug", scriptName, methodName, "It is a Monitor profile migration")
					framework.log("debug", scriptName, methodName, "update Monitor widgets")
					updateMonitorWidgets('', '', clusterName)
	                #endif
	        else:
			framework.log("info", scriptName, methodName, "no cluster")
			nodeId = getScopeId(cellName,nodeName,'')
			framework.log("debug", scriptName, methodName, "nodeId is: " + str(nodeId))
			serverList = wsadminToList(AdminConfig.list('Server',nodeId))
			for server in serverList:		
				serverName = AdminConfig.showAttribute(server,'name')
				framework.log("info", scriptName, methodName, 'serverName = ' + str(serverName))
				scopeAtt = 'WebSphere:cell=' + cellName + ',node=' + nodeName + ',server=' + serverName
				scopePath = getScopePath(cellName,nodeName,serverName)
				framework.log("debug", scriptName, methodName, 'scopeAtt = ' + str(scopeAtt))
				framework.log("debug", scriptName, methodName, 'scopePath = ' + str(scopePath))
				if (not checkIfBSpaceMigrationRequired(scopeAtt,scopePath)):					
					framework.log("info", scriptName, methodName, "No Business Space configured in target server, exit Business Space migration in target server")
					return;
				#endif
				
				version = checkBSpaceVersion(nodeName,serverName,'',scopeAtt,scopePath)
				framework.log("info", scriptName, methodName, "source version -- " + version)
				
				if (version == 'v6'):
				        uninstallPreOOBWidgetApp(scopeAtt)
				        #bpm.upgrade.profile.type=wbiserver
					#wbi.upgrade.profile.type=WPS
					if (profileType != None):
						if (profileType2 != None):
							if(profileType == 'wbiserver'):
								if(profileType2 == 'WPS'):
									framework.log("info", scriptName, methodName, "Migrate Business Space for bpm_adv.")
									installBusinessSpace(serverName, nodeName, '', 'bpm_adv')
									updateBusinessSpace(serverName, nodeName, '', 'v6', 'bpm_adv')
								#endif
							else:
								framework.log("info", scriptName, methodName, "Migrate Business Space for bspace.")
								installBusinessSpace(serverName, nodeName, '', 'bspace')
								updateBusinessSpace(serverName, nodeName, '', 'v6', 'bspace')
							#endif
						#endif	
					#endif
				        
				        sys.argv = ['-usedefault', '-nodeName', nodeName, '-serverName', serverName]
					execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py', {})
				        
				        uninstallPreBSpaceRuntime(scopeAtt)
				        removeDataSource("jdbc/bpm/BusinessSpace",scopePath)			        
				elif (version == 'v7.0'):
					#bpm.upgrade.profile.type=wbiserver
					#wbi.upgrade.profile.type=WPS
					if (profileType != None):
						if (profileType2 != None):
							if(profileType == 'wbiserver'):
								if(profileType2 == 'WPS'):
									framework.log("info", scriptName, methodName, "Migrate Business Space for bpm_adv.")
									updateBusinessSpace(serverName, nodeName, '', 'v70', 'bpm_adv')
								#endif
							else:
								framework.log("info", scriptName, methodName, "Migrate Business Space for bspace.")
								updateBusinessSpace(serverName, nodeName, '', 'v70', 'bspace')
							#endif
						#endif	
					#endif
				        
				        sys.argv = ['-usedefault', '-nodeName', nodeName, '-serverName', serverName]
					execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py', {})
				        
				        framework.log("debug", scriptName, methodName, "Profile Type is : " + profileType)
					if (profileType.find('wbmonitor') >= 0):
						framework.log("debug", scriptName, methodName, "It is a Monitor profile migration")
						framework.log("debug", scriptName, methodName, "update Monitor widgets")
						updateMonitorWidgets(serverName, nodeName, '')
			        elif (version == 'v7.5'):
			        	#bpm.upgrade.profile.type=wbiserver
					#wbi.upgrade.profile.type=WPS
					if (profileType != None):
						if (profileType2 != None):
							if(profileType == 'wbiserver'):
								if(profileType2 == 'WPS'):
									framework.log("info", scriptName, methodName, "Migrate Business Space for bpm_adv.")
									updateBusinessSpace(serverName, nodeName, '', 'v75', 'bpm_adv')
								#endif
							else:
								framework.log("info", scriptName, methodName, "Migrate Business Space for bspace.")
								updateBusinessSpace(serverName, nodeName, '', 'v75', 'bspace')
							#endif
						#endif	
					#endif
				        
				        sys.argv = ['-usedefault', '-nodeName', nodeName, '-serverName', serverName]
					execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py', {})
				        
				        framework.log("debug", scriptName, methodName, "Profile Type is : " + profileType)
					if (profileType.find('wbmonitor') >= 0):
						framework.log("debug", scriptName, methodName, "It is a Monitor profile migration")
						framework.log("debug", scriptName, methodName, "update Monitor widgets")
						updateMonitorWidgets(serverName, nodeName, '')
			        #endif
			framework.log("info", scriptName, methodName, "******************************************* Message begin for remote endpoint *******************************************")
			framework.log("info", scriptName, methodName, "If you have Business Space widgets enabled for remote endpoint in source installation, you must migrate them manually to the target installation.")
			framework.log("info", scriptName, methodName, "Please see the topic 'Postmigration tasks for Business Space powered by WebSphere' in InfoCenter.")
			framework.log("info", scriptName, methodName, "******************************************* Message end for remote endpoint *******************************************")	
		#endIf	
	#endIf
	

	if (flag_success == 0):
		framework.log("error", scriptName, methodName, "migration failed due to " + failureReason)
	else:
		AdminConfig.save();	
			
		updateImportingFlags();
		copyBusinessSpaceSystemFiles();
		
		framework.log("info", scriptName, methodName, "Business Space Migration succeeds.")
	#endIf

#endDef



#-----------------------------------------------------------------
# Start Main function
#-----------------------------------------------------------------
scriptName = "updateBSpaceApp";

# create a global variable for class BPMMigrationFramework
framework = BPMMigrationFramework()

main();

#sys.argv = ['-usedefault']
#execfile(getWASHome() + '/BusinessSpace/scripts/configBSpaceTransport.py')
#configBSpaceTransport.main('-allowhttp')
#-----------------------------------------------------------------
# End Main function
#-----------------------------------------------------------------